#ifndef YCF_YIELDING_C_FUN_HELPERS
#define YCF_YIELDING_C_FUN_HELPERS 1
#include <string.h>
#include <stdio.h>
#include <stdlib.h>

/*
 * YCF_GCC_DIAG_ON and YCF_GCC_DIAG_OFF can be used to temporarly
 * disable a gcc or clang warning in a file.
 *
 * Example:
 * YCF_GCC_DIAG_OFF(unused-function)
 * static int test(){ return 0;}
 * YCF_GCC_DIAG_ON(unused-function)
 *
 * These macros were originally authored by Jonathan Wakely and has
 * been modified by Patrick Horgan.
 *
 * Source: http://dbp-consulting.com/tutorials/SuppressingGCCWarnings.html
 *
 */
#if defined(_MSC_VER)
#  define YCF_GCC_DIAG_OFF(x) __pragma(warning(push, 0))
#  define YCF_GCC_DIAG_ON(x)  __pragma(warning(pop))
#elif ((__GNUC__ * 100) + __GNUC_MINOR__) >= 402
#define YCF_GCC_DIAG_STR(s) #s
#define YCF_GCC_DIAG_JOINSTR(x,y) YCF_GCC_DIAG_STR(x ## y)
# define YCF_GCC_DIAG_DO_PRAGMA(x) _Pragma (#x)
# define YCF_GCC_DIAG_PRAGMA(x) YCF_GCC_DIAG_DO_PRAGMA(GCC diagnostic x)
# if ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406
#  define YCF_GCC_DIAG_OFF(x) YCF_GCC_DIAG_PRAGMA(push) \
      YCF_GCC_DIAG_PRAGMA(ignored YCF_GCC_DIAG_JOINSTR(-W,x))
#  define YCF_GCC_DIAG_ON(x) YCF_GCC_DIAG_PRAGMA(pop)
# else
#  define YCF_GCC_DIAG_OFF(x) YCF_GCC_DIAG_PRAGMA(ignored YCF_GCC_DIAG_JOINSTR(-W,x))
#  define YCF_GCC_DIAG_ON(x)  YCF_GCC_DIAG_PRAGMA(warning YCF_GCC_DIAG_JOINSTR(-W,x))
# endif
#else
# define YCF_GCC_DIAG_OFF(x)
# define YCF_GCC_DIAG_ON(x)
#endif
#ifdef __GNUC__
#  if __GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 5) || defined(__clang__)
#    define YCF_GCC_ATTRIBUTE_UNUSED __attribute__ ((unused))
#  else
#    define YCF_GCC_ATTRIBUTE_UNUSED
#  endif
#else
#  define YCF_GCC_ATTRIBUTE_UNUSED
#endif

typedef void* (*ycf_yield_alloc_type) (size_t,void*);
typedef void (*ycf_yield_free_type) (void*,void*);

struct ycf_alloc_data {
  size_t size;
  size_t max_size;
  int needs_freeing;
  char* data;
};

#define YCF_ALLOC_NEXT_BLOCK() (\
 ycf_frame_alloc_data.data == NULL \
   ? NULL \
   : ((void*)(&ycf_frame_alloc_data.data[ycf_frame_alloc_data.size]))\
)
#define YCF_ALLOC_NEXT_MAX_SIZE() (\
 ycf_frame_alloc_data.data == NULL \
   ? ycf_frame_alloc_data.max_size \
   : (ycf_frame_alloc_data.max_size - ycf_frame_alloc_data.size)\
)

/* Macros for special code sections */
#define ON_SAVE_YIELD_STATE ON_SAVE_YIELD_STATE
#define ON_RESTORE_YIELD_STATE ON_RESTORE_YIELD_STATE
#define ON_DESTROY_STATE ON_DESTROY_STATE
#define ON_RETURN ON_RETURN
#define ON_DESTROY_STATE_OR_RETURN ON_DESTROY_STATE_OR_RETURN
#define YCF_SPECIAL_CODE_START(PARAM) \
   /*special_code_start:PARAM*/       \
   if(0){
#define YCF_SPECIAL_CODE_END() \
   }\
   /*special_code_end*/

YCF_GCC_ATTRIBUTE_UNUSED
static void* ycf_stack_alloc(size_t size,
                             struct ycf_alloc_data* data,
                             ycf_yield_alloc_type allocator,
                             void* ycf_yield_alloc_free_context,
                             size_t default_stack_size){
  void * ret = NULL;
  if (data->data == NULL) {
    if (default_stack_size == 0) {
      fprintf(stderr, "ycf_alloc: not enough stack!! (max size = 0)\n");
      exit(1);
    }
    data->data = allocator(default_stack_size, ycf_yield_alloc_free_context);
    data->needs_freeing = 1;
    data->max_size = default_stack_size;
    data->size = 0;
  }
  if (data->size + size > data->max_size) {
    fprintf(stderr, "ycf_alloc: not enough stack! (max size = %zu)\n", default_stack_size);
    exit(1);
  }
  ret = &data->data[data->size];
  data->size = data->size + size + (sizeof(void * ) - (size % sizeof(void * ))) % sizeof(void * );
  return ret;
}
YCF_GCC_ATTRIBUTE_UNUSED
static void ycf_destroy_stack_allocator(struct ycf_alloc_data* data,
                                        ycf_yield_free_type freer,
                                        void* ycf_yield_alloc_free_context){
  if(data->needs_freeing){
    freer(data->data, ycf_yield_alloc_free_context);
  }
}


#include <limits.h>
#define YCF_MAX_NR_OF_REDS LONG_MAX
#define YCF_NR_OF_REDS_LEFT() ycf_nr_of_reductions
#define YCF_SET_NR_OF_REDS_LEFT(NEW_NR_OF_REDS_LEFT) \
  do{ycf_nr_of_reductions = (NEW_NR_OF_REDS_LEFT);}while(0)

#define YCF_GET_EXTRA_CONTEXT() ycf_extra_context

#define YCF_IS_YIELDED(CTX) (CTX != NULL)

#define YCF_YIELD_CODE_GENERATED 1


/* end of YCF_YIELDING_C_FUN_HELPERS guard */
#endif



struct gen_ycf_trap_state_for_hashmap_from_validated_list;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_validated_list_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_validated_list_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static Eterm hashmap_from_validated_list_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process *p_N224_N246,
                                         Eterm list_N225_N247,
                                         Eterm fill_value_N226_N248,
                                         Uint size_N227_N249);



struct gen_ycf_trap_state_for_maps_from_list_1_helper;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_from_list_1_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_from_list_1_helper_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static BIF_RETTYPE maps_from_list_1_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N197_N205, Eterm* bif_args_N198_N206);



struct gen_ycf_trap_state_for_maps_from_keys_2_helper;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_from_keys_2_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_from_keys_2_helper_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static BIF_RETTYPE maps_from_keys_2_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N182_N190, Eterm* bif_args_N183_N191);



struct gen_ycf_trap_state_for_maps_values_1_helper;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_values_1_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_values_1_helper_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static BIF_RETTYPE maps_values_1_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N165_N175, Eterm* bif_args_N166_N176);



struct gen_ycf_trap_state_for_maps_keys_1_helper;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_keys_1_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_keys_1_helper_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static BIF_RETTYPE maps_keys_1_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N146_N156, Eterm* bif_args_N147_N157);



struct gen_ycf_trap_state_for_hashmap_from_chunked_array;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_chunked_array_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_chunked_array_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* **Important Note**
 *
 * A yielding version of this function is generated with YCF. This
 * means that the code has to follow some restrictions. See note about
 * YCF near the top of the file for more information.
 */
static Eterm hashmap_from_chunked_array_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,ErtsHeapFactory *factory_N109_N133, hxnode_t *hxns_N110_N134, Uint n_N111_N135,
                                        Uint size_N112_N136, int is_root_N113_N137,
                                        ErtsAlcType_t temp_memory_allocator_N114_N138);



struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_sorted_unique_array_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_sorted_unique_array_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */



/* **Important Note**
 *
 * A yielding version of this function is generated with YCF. This
 * means that the code has to follow some restrictions. See note about
 * YCF near the top of the file for more information.
 */
static Eterm hashmap_from_sorted_unique_array_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,ErtsHeapFactory* factory_N69_N86,
                                              hxnode_t *hxns_N70_N87, Uint n_N71_N88, int lvl_N72_N89,
                                              ErtsAlcType_t temp_memory_allocator_N73_N90);



struct gen_ycf_trap_state_for_hashmap_from_unsorted_array;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_unsorted_array_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_unsorted_array_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */



/* **Important Note**
 *
 * A yielding version of this function is generated with YCF. This
 * means that the code has to follow some restrictions. See note about
 * YCF near the top of the file for more information.
 */
static Eterm hashmap_from_unsorted_array_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,ErtsHeapFactory* factory_N40_N55,
                                         hxnode_t *hxns_N41_N56, Uint n_N42_N57,
                                         int reject_dupkeys_N43_N58,
                                         ErtsAlcType_t temp_memory_allocator_N44_N59);



struct gen_ycf_trap_state_for_hashmap_values;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_values_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_values_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static Eterm hashmap_values_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N23_N31, Eterm node_N24_N32);



struct gen_ycf_trap_state_for_hashmap_keys;

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_keys_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_keys_ycf_gen_destroy(void* ycf_my_trap_state_param);
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

static Eterm hashmap_keys_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N7_N15, Eterm node_N8_N16);



struct gen_ycf_trap_state_for_hashmap_keys {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm stack_default_wstack_N1_N9[16];
    ErtsWStack stack_N2_N10;
    hashmap_head_t* root_N3_N11;
    Eterm *hp_N4_N12;
    Eterm *kv_N5_N13;
    Eterm res_N6_N14;Process* p_N7_N15; Eterm node_N8_N16;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_keys_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_hashmap_keys* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm stack_default_wstack_N1_N9[16];
    ErtsWStack stack_N2_N10;
    hashmap_head_t* root_N3_N11;
    Eterm *hp_N4_N12;
    Eterm *kv_N5_N13;
    Eterm res_N6_N14;Process* p_N7_N15; Eterm node_N8_N16;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    memcpy(stack_default_wstack_N1_N9, ycf_my_trap_state->stack_default_wstack_N1_N9, 16 *  sizeof(
    Eterm));
    stack_N2_N10 = ycf_my_trap_state->stack_N2_N10;
    root_N3_N11 = ycf_my_trap_state->root_N3_N11;
    hp_N4_N12 = ycf_my_trap_state->hp_N4_N12;
    kv_N5_N13 = ycf_my_trap_state->kv_N5_N13;
    res_N6_N14 = ycf_my_trap_state->res_N6_N14;
    p_N7_N15 = ycf_my_trap_state->p_N7_N15;
    node_N8_N16 = ycf_my_trap_state->node_N8_N16;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{

    {
        DESTROY_WSTACK_EXPLICIT_DEFAULT_ARRAY(stack_N2_N10, stack_default_wstack_N1_N9);
    }}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_keys_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_hashmap_keys* ycf_my_trap_state = *ycf_trap_state;
return hashmap_keys_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N7_N15,ycf_my_trap_state->node_N8_N16)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static Eterm hashmap_keys_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N7_N15, Eterm node_N8_N16) {
    Eterm stack_default_wstack_N1_N9[16];
    ErtsWStack stack_N2_N10;
    hashmap_head_t* root_N3_N11;
    Eterm *hp_N4_N12;
    Eterm *kv_N5_N13;
    Eterm res_N6_N14;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_hashmap_keys* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    memcpy(stack_default_wstack_N1_N9, ycf_my_trap_state->stack_default_wstack_N1_N9, 16 *  sizeof(
    Eterm));
    stack_N2_N10 = ycf_my_trap_state->stack_N2_N10;
    root_N3_N11 = ycf_my_trap_state->root_N3_N11;
    hp_N4_N12 = ycf_my_trap_state->hp_N4_N12;
    kv_N5_N13 = ycf_my_trap_state->kv_N5_N13;
    res_N6_N14 = ycf_my_trap_state->res_N6_N14;
    p_N7_N15 = ycf_my_trap_state->p_N7_N15;
    node_N8_N16 = ycf_my_trap_state->node_N8_N16;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;

}
  }
}
{

}
    res_N6_N14 = NIL;
#if DEF_WSTACK_SIZE != (16)
#error "The macro DEF_WSTACK_SIZE has changed from 16 (need to change constant above)"
    /* We cannot use "UWord stack_default_wstack[DEF_WSTACK_SIZE];"
       because macros are not expanded before the code is passed to
       YCF, and YCF needs to know the size of the array */
#endif
    stack_N2_N10 = WSTACK_DEFAULT_VALUE(stack_default_wstack_N1_N9, ERTS_ALC_T_MAP_TRAP);
/* YCF Replaced special code */

/* YCF Replaced special code */


    root_N3_N11 = (hashmap_head_t*) boxed_val(node_N8_N16);
    hp_N4_N12  = HAlloc(p_N7_N15, root_N3_N11->size * 2);
    hashmap_iterator_init(&stack_N2_N10, node_N8_N16, 0);
    while ((kv_N5_N13=hashmap_iterator_next(&stack_N2_N10)) != NULL)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 1;
  goto ycf_do_yield_label_hashmap_keys;
  ycf_yield_location_label_1:;
}

}
    {
	res_N6_N14 = CONS(hp_N4_N12, CAR(kv_N5_N13), res_N6_N14);
	hp_N4_N12 += 2;
    }

}
    DESTROY_WSTACK_EXPLICIT_DEFAULT_ARRAY(stack_N2_N10, stack_default_wstack_N1_N9);
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

    return res_N6_N14;
}

{
  struct gen_ycf_trap_state_for_hashmap_keys* ycf_my_trap_state;
  ycf_do_yield_label_hashmap_keys:;

    {
        ENSURE_WSTACK_HEAP_STACK_ARRAY(stack_N2_N10, stack_default_wstack_N1_N9);
    }

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_hashmap_keys), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    memcpy(ycf_my_trap_state->stack_default_wstack_N1_N9, stack_default_wstack_N1_N9, 16 *  sizeof(
    Eterm));
    ycf_my_trap_state->stack_N2_N10 = stack_N2_N10;
    ycf_my_trap_state->root_N3_N11 = root_N3_N11;
    ycf_my_trap_state->hp_N4_N12 = hp_N4_N12;
    ycf_my_trap_state->kv_N5_N13 = kv_N5_N13;
    ycf_my_trap_state->res_N6_N14 = res_N6_N14;
    ycf_my_trap_state->p_N7_N15 = p_N7_N15;
    ycf_my_trap_state->node_N8_N16 = node_N8_N16;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   Eterm  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_hashmap_values {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm stack_default_wstack_N17_N25[16];
    ErtsWStack stack_N18_N26;
    hashmap_head_t* root_N19_N27;
    Eterm *hp_N20_N28;
    Eterm *kv_N21_N29;
    Eterm res_N22_N30;Process* p_N23_N31; Eterm node_N24_N32;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_values_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_hashmap_values* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm stack_default_wstack_N17_N25[16];
    ErtsWStack stack_N18_N26;
    hashmap_head_t* root_N19_N27;
    Eterm *hp_N20_N28;
    Eterm *kv_N21_N29;
    Eterm res_N22_N30;Process* p_N23_N31; Eterm node_N24_N32;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    memcpy(stack_default_wstack_N17_N25, ycf_my_trap_state->stack_default_wstack_N17_N25, 16 *  sizeof(
    Eterm));
    stack_N18_N26 = ycf_my_trap_state->stack_N18_N26;
    root_N19_N27 = ycf_my_trap_state->root_N19_N27;
    hp_N20_N28 = ycf_my_trap_state->hp_N20_N28;
    kv_N21_N29 = ycf_my_trap_state->kv_N21_N29;
    res_N22_N30 = ycf_my_trap_state->res_N22_N30;
    p_N23_N31 = ycf_my_trap_state->p_N23_N31;
    node_N24_N32 = ycf_my_trap_state->node_N24_N32;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{

    {
        DESTROY_WSTACK_EXPLICIT_DEFAULT_ARRAY(stack_N18_N26, stack_default_wstack_N17_N25);
    }}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_values_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_hashmap_values* ycf_my_trap_state = *ycf_trap_state;
return hashmap_values_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N23_N31,ycf_my_trap_state->node_N24_N32)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static Eterm hashmap_values_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N23_N31, Eterm node_N24_N32) {
    Eterm stack_default_wstack_N17_N25[16];
    ErtsWStack stack_N18_N26;
    hashmap_head_t* root_N19_N27;
    Eterm *hp_N20_N28;
    Eterm *kv_N21_N29;
    Eterm res_N22_N30;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_hashmap_values* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    memcpy(stack_default_wstack_N17_N25, ycf_my_trap_state->stack_default_wstack_N17_N25, 16 *  sizeof(
    Eterm));
    stack_N18_N26 = ycf_my_trap_state->stack_N18_N26;
    root_N19_N27 = ycf_my_trap_state->root_N19_N27;
    hp_N20_N28 = ycf_my_trap_state->hp_N20_N28;
    kv_N21_N29 = ycf_my_trap_state->kv_N21_N29;
    res_N22_N30 = ycf_my_trap_state->res_N22_N30;
    p_N23_N31 = ycf_my_trap_state->p_N23_N31;
    node_N24_N32 = ycf_my_trap_state->node_N24_N32;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;

}
  }
}
{

}
    res_N22_N30 = NIL;
#if DEF_WSTACK_SIZE != (16)
#error "The macro DEF_WSTACK_SIZE has changed from 16 (need to change constant above)"
    /* We cannot use "UWord stack_default_wstack[DEF_WSTACK_SIZE];"
       because macros are not expanded before the code is passed to
       YCF, and YCF needs to know the size of the array */
#endif
    stack_N18_N26 = WSTACK_DEFAULT_VALUE(stack_default_wstack_N17_N25, ERTS_ALC_T_MAP_TRAP);
/* YCF Replaced special code */

/* YCF Replaced special code */



    root_N19_N27 = (hashmap_head_t*) boxed_val(node_N24_N32);
    hp_N20_N28  = HAlloc(p_N23_N31, root_N19_N27->size * 2);
    hashmap_iterator_init(&stack_N18_N26, node_N24_N32, 0);
    while ((kv_N21_N29=hashmap_iterator_next(&stack_N18_N26)) != NULL)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 1;
  goto ycf_do_yield_label_hashmap_values;
  ycf_yield_location_label_1:;
}

}
    {
	res_N22_N30 = CONS(hp_N20_N28, CDR(kv_N21_N29), res_N22_N30);
	hp_N20_N28 += 2;
    }

}
    DESTROY_WSTACK_EXPLICIT_DEFAULT_ARRAY(stack_N18_N26, stack_default_wstack_N17_N25);
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

    return res_N22_N30;
}

{
  struct gen_ycf_trap_state_for_hashmap_values* ycf_my_trap_state;
  ycf_do_yield_label_hashmap_values:;

    {
        ENSURE_WSTACK_HEAP_STACK_ARRAY(stack_N18_N26, stack_default_wstack_N17_N25);
    }

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_hashmap_values), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    memcpy(ycf_my_trap_state->stack_default_wstack_N17_N25, stack_default_wstack_N17_N25, 16 *  sizeof(
    Eterm));
    ycf_my_trap_state->stack_N18_N26 = stack_N18_N26;
    ycf_my_trap_state->root_N19_N27 = root_N19_N27;
    ycf_my_trap_state->hp_N20_N28 = hp_N20_N28;
    ycf_my_trap_state->kv_N21_N29 = kv_N21_N29;
    ycf_my_trap_state->res_N22_N30 = res_N22_N30;
    ycf_my_trap_state->p_N23_N31 = p_N23_N31;
    ycf_my_trap_state->node_N24_N32 = node_N24_N32;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   Eterm  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_hashmap_from_unsorted_array {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Uint jx_N35_N48;
    Uint ix_N36_N49;
    Uint lx_N37_N50;
    Uint cx_N38_N51;
    Eterm res_N39_N52;
	Eterm *hp_N33_N53;
	Eterm *hp_N34_N54;
void* ycf_sub_fun_trap_state_wb_N45;

void* ycf_sub_fun_trap_state_wb_N46;

void* ycf_sub_fun_trap_state_wb_N47;ErtsHeapFactory* factory_N40_N55;
                                         hxnode_t *hxns_N41_N56; Uint n_N42_N57;
                                         int reject_dupkeys_N43_N58;
                                         ErtsAlcType_t temp_memory_allocator_N44_N59;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_unsorted_array_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_hashmap_from_unsorted_array* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Uint jx_N35_N48;
    Uint ix_N36_N49;
    Uint lx_N37_N50;
    Uint cx_N38_N51;
    Eterm res_N39_N52;
	Eterm *hp_N33_N53;
	Eterm *hp_N34_N54;
void* ycf_sub_fun_trap_state_wb_N45;

void* ycf_sub_fun_trap_state_wb_N46;

void* ycf_sub_fun_trap_state_wb_N47;ErtsHeapFactory* factory_N40_N55;
                                         hxnode_t *hxns_N41_N56; Uint n_N42_N57;
                                         int reject_dupkeys_N43_N58;
                                         ErtsAlcType_t temp_memory_allocator_N44_N59;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    jx_N35_N48 = ycf_my_trap_state->jx_N35_N48;
    ix_N36_N49 = ycf_my_trap_state->ix_N36_N49;
    lx_N37_N50 = ycf_my_trap_state->lx_N37_N50;
    cx_N38_N51 = ycf_my_trap_state->cx_N38_N51;
    res_N39_N52 = ycf_my_trap_state->res_N39_N52;
    hp_N33_N53 = ycf_my_trap_state->hp_N33_N53;
    hp_N34_N54 = ycf_my_trap_state->hp_N34_N54;
    ycf_sub_fun_trap_state_wb_N45 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N45;
    ycf_sub_fun_trap_state_wb_N46 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N46;
    ycf_sub_fun_trap_state_wb_N47 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N47;
    factory_N40_N55 = ycf_my_trap_state->factory_N40_N55;
    hxns_N41_N56 = ycf_my_trap_state->hxns_N41_N56;
    n_N42_N57 = ycf_my_trap_state->n_N42_N57;
    reject_dupkeys_N43_N58 = ycf_my_trap_state->reject_dupkeys_N43_N58;
    temp_memory_allocator_N44_N59 = ycf_my_trap_state->temp_memory_allocator_N44_N59;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N45 != NULL)
{     erts_qsort_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N45);
  }
}
{
  if(ycf_sub_fun_trap_state_wb_N46 != NULL)
{     erts_qsort_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N46);
  }
}
{
  if(ycf_sub_fun_trap_state_wb_N47 != NULL)
{     hashmap_from_sorted_unique_array_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N47);
  }
}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_unsorted_array_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_hashmap_from_unsorted_array* ycf_my_trap_state = *ycf_trap_state;
return hashmap_from_unsorted_array_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->factory_N40_N55,ycf_my_trap_state->hxns_N41_N56,ycf_my_trap_state->n_N42_N57,ycf_my_trap_state->reject_dupkeys_N43_N58,ycf_my_trap_state->temp_memory_allocator_N44_N59)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */


/* **Important Note**
 *
 * A yielding version of this function is generated with YCF. This
 * means that the code has to follow some restrictions. See note about
 * YCF near the top of the file for more information.
 */
static Eterm hashmap_from_unsorted_array_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,ErtsHeapFactory* factory_N40_N55,
                                         hxnode_t *hxns_N41_N56, Uint n_N42_N57,
                                         int reject_dupkeys_N43_N58,
                                         ErtsAlcType_t temp_memory_allocator_N44_N59) {
    Uint jx_N35_N48;
    Uint ix_N36_N49;
    Uint lx_N37_N50;
    Uint cx_N38_N51;
    Eterm res_N39_N52;
	Eterm *hp_N33_N53;
	Eterm *hp_N34_N54;
void* ycf_sub_fun_trap_state_wb_N45;

void* ycf_sub_fun_trap_state_wb_N46;

void* ycf_sub_fun_trap_state_wb_N47;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_hashmap_from_unsorted_array* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    jx_N35_N48 = ycf_my_trap_state->jx_N35_N48;
    ix_N36_N49 = ycf_my_trap_state->ix_N36_N49;
    lx_N37_N50 = ycf_my_trap_state->lx_N37_N50;
    cx_N38_N51 = ycf_my_trap_state->cx_N38_N51;
    res_N39_N52 = ycf_my_trap_state->res_N39_N52;
    hp_N33_N53 = ycf_my_trap_state->hp_N33_N53;
    hp_N34_N54 = ycf_my_trap_state->hp_N34_N54;
    ycf_sub_fun_trap_state_wb_N45 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N45;
    ycf_sub_fun_trap_state_wb_N46 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N46;
    ycf_sub_fun_trap_state_wb_N47 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N47;
    factory_N40_N55 = ycf_my_trap_state->factory_N40_N55;
    hxns_N41_N56 = ycf_my_trap_state->hxns_N41_N56;
    n_N42_N57 = ycf_my_trap_state->n_N42_N57;
    reject_dupkeys_N43_N58 = ycf_my_trap_state->reject_dupkeys_N43_N58;
    temp_memory_allocator_N44_N59 = ycf_my_trap_state->temp_memory_allocator_N44_N59;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;
case 2: goto ycf_yield_location_label_2;
case 3: goto ycf_yield_location_label_3;
case 4: goto ycf_yield_location_label_4;
case 5: goto ycf_yield_location_label_5;
case 6: goto ycf_yield_location_label_6;
case 7: goto ycf_yield_location_label_7;
case 8: goto ycf_yield_location_label_8;
case 9: goto ycf_yield_location_label_9;
case 10: goto ycf_yield_location_label_10;
case 11: goto ycf_yield_location_label_11;
case 12: goto ycf_yield_location_label_12;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N45 = NULL;

ycf_sub_fun_trap_state_wb_N46 = NULL;

ycf_sub_fun_trap_state_wb_N47 = NULL;

}
    jx_N35_N48 = 0;
    ix_N36_N49 = 0;

    if (n_N42_N57 == 0)
{
    {
	hp_N33_N53 = erts_produce_heap(factory_N40_N55, 2, 0);
	hp_N33_N53[0] = MAP_HEADER_HAMT_HEAD_BITMAP(0);
	hp_N33_N53[1] = 0;
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


	return make_hashmap(hp_N33_N53);
}
    }

}
{

ycf_sub_fun_trap_state_wb_N45 = NULL;
{
 erts_qsort_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N45,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,hxns_N41_N56, n_N42_N57, sizeof(hxnode_t), hxnodecmp);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N45)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_1:;
    erts_qsort_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N45,
                            ycf_extra_context);
}


}
/* YCF Replaced special code */

}


    ix_N36_N49 = 0, cx_N38_N51 = 0;
    while(ix_N36_N49 < n_N42_N57 - 1)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 4;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_4:;
}

}
    {
	if (hxns_N41_N56[ix_N36_N49].hx == hxns_N41_N56[ix_N36_N49+1].hx)
{
    {

	    /* find region of equal hash values */
	    jx_N35_N48 = ix_N36_N49 + 1;
	    while(jx_N35_N48 < n_N42_N57 && hxns_N41_N56[ix_N36_N49].hx == hxns_N41_N56[jx_N35_N48].hx)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 5;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_5:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 6;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_6:;
}

}
    { jx_N35_N48++; }

}

}
{


ycf_sub_fun_trap_state_wb_N46 = NULL;
{
 erts_qsort_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N46,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,&hxns_N41_N56[ix_N36_N49], jx_N35_N48 - ix_N36_N49, sizeof(hxnode_t), hxnodecmpkey);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N46)){
   ycf_trap_location = 2;
   goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_2:;
    erts_qsort_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N46,
                            ycf_extra_context);
}


}
/* YCF Replaced special code */

}



	    while(ix_N36_N49 < jx_N35_N48)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 7;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_7:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 8;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_8:;
}

}
    {
		lx_N37_N50 = ix_N36_N49;
		while(++ix_N36_N49 < jx_N35_N48 && EQ(CAR(list_val(hxns_N41_N56[ix_N36_N49].val)),
				      CAR(list_val(hxns_N41_N56[lx_N37_N50].val))))
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 9;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_9:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 10;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_10:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 11;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_11:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 12;
  goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_12:;
}

}
    {
                    if (reject_dupkeys_N43_N58)
{
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

   
                        return THE_NON_VALUE;
}

}

                    if (hxns_N41_N56[ix_N36_N49].i > hxns_N41_N56[lx_N37_N50].i)
{
    {
			lx_N37_N50 = ix_N36_N49;
		    }

}
		}

}

}

}

}
		hxns_N41_N56[cx_N38_N51].hx  = hxns_N41_N56[lx_N37_N50].hx;
		hxns_N41_N56[cx_N38_N51].val = hxns_N41_N56[lx_N37_N50].val;
		cx_N38_N51++;
	    }

}

}
	    ix_N36_N49 = jx_N35_N48;
	    continue;
	}

}
	if (ix_N36_N49 > cx_N38_N51)
{
    {
	    hxns_N41_N56[cx_N38_N51].hx  = hxns_N41_N56[ix_N36_N49].hx;
	    hxns_N41_N56[cx_N38_N51].val = hxns_N41_N56[ix_N36_N49].val;
	}

}
	cx_N38_N51++;
	ix_N36_N49++;
    }

}

    if (ix_N36_N49 < n_N42_N57)
{
    {
	hxns_N41_N56[cx_N38_N51].hx  = hxns_N41_N56[ix_N36_N49].hx;
	hxns_N41_N56[cx_N38_N51].val = hxns_N41_N56[ix_N36_N49].val;
	cx_N38_N51++;
    }

}

    if (cx_N38_N51 > 1)
{
{


ycf_sub_fun_trap_state_wb_N47 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_from_sorted_unique_array_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N47,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,factory_N40_N55, hxns_N41_N56, cx_N38_N51, 0, temp_memory_allocator_N44_N59);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N47)){
   ycf_trap_location = 3;
   goto ycf_do_yield_label_hashmap_from_unsorted_array;
  ycf_yield_location_label_3:;
   ycf_tmp_fun_call_tmp_var =  hashmap_from_sorted_unique_array_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N47,
                            ycf_extra_context);
}

	/* recursive decompose array */
	res_N39_N52 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}


} else
{
    {

	/* we only have one item, either because n was 1 or
	 * because we hade multiples of the same key.
	 *
	 * hash value has been swizzled, need to drag it down to get the
	 * correct slot. */

	hp_N34_N54    = erts_produce_heap(factory_N40_N55, HAMT_HEAD_BITMAP_SZ(1), 0);
	hp_N34_N54[0] = MAP_HEADER_HAMT_HEAD_BITMAP(1 << ((hxns_N41_N56[0].hx >> 0x1c) & 0xf));
	hp_N34_N54[1] = 1;
	hp_N34_N54[2] = hxns_N41_N56[0].val;
	res_N39_N52   = make_hashmap(hp_N34_N54);
    }

}
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


    return res_N39_N52;
}

{
  struct gen_ycf_trap_state_for_hashmap_from_unsorted_array* ycf_my_trap_state;
  ycf_do_yield_label_hashmap_from_unsorted_array:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_hashmap_from_unsorted_array), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->jx_N35_N48 = jx_N35_N48;
    ycf_my_trap_state->ix_N36_N49 = ix_N36_N49;
    ycf_my_trap_state->lx_N37_N50 = lx_N37_N50;
    ycf_my_trap_state->cx_N38_N51 = cx_N38_N51;
    ycf_my_trap_state->res_N39_N52 = res_N39_N52;
    ycf_my_trap_state->hp_N33_N53 = hp_N33_N53;
    ycf_my_trap_state->hp_N34_N54 = hp_N34_N54;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N45 = ycf_sub_fun_trap_state_wb_N45;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N46 = ycf_sub_fun_trap_state_wb_N46;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N47 = ycf_sub_fun_trap_state_wb_N47;
    ycf_my_trap_state->factory_N40_N55 = factory_N40_N55;
    ycf_my_trap_state->hxns_N41_N56 = hxns_N41_N56;
    ycf_my_trap_state->n_N42_N57 = n_N42_N57;
    ycf_my_trap_state->reject_dupkeys_N43_N58 = reject_dupkeys_N43_N58;
    ycf_my_trap_state->temp_memory_allocator_N44_N59 = temp_memory_allocator_N44_N59;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   Eterm  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm res_N60_N77;
    Uint i_N61_N78;
    Uint ix_N62_N79;
    Uint jx_N63_N80;
    Uint elems_N64_N81;
    Uint32 sw_N65_N82;
    Uint32 hx_N66_N83;
    Eterm val_N67_N84;
    hxnode_t *tmp_N68_N85;

void* ycf_sub_fun_trap_state_wb_N74;

void* ycf_sub_fun_trap_state_wb_N75;
void* ycf_sub_fun_trap_state_wb_N76;ErtsHeapFactory* factory_N69_N86;
                                              hxnode_t *hxns_N70_N87; Uint n_N71_N88; int lvl_N72_N89;
                                              ErtsAlcType_t temp_memory_allocator_N73_N90;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_sorted_unique_array_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm res_N60_N77;
    Uint i_N61_N78;
    Uint ix_N62_N79;
    Uint jx_N63_N80;
    Uint elems_N64_N81;
    Uint32 sw_N65_N82;
    Uint32 hx_N66_N83;
    Eterm val_N67_N84;
    hxnode_t *tmp_N68_N85;

void* ycf_sub_fun_trap_state_wb_N74;

void* ycf_sub_fun_trap_state_wb_N75;
void* ycf_sub_fun_trap_state_wb_N76;ErtsHeapFactory* factory_N69_N86;
                                              hxnode_t *hxns_N70_N87; Uint n_N71_N88; int lvl_N72_N89;
                                              ErtsAlcType_t temp_memory_allocator_N73_N90;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    res_N60_N77 = ycf_my_trap_state->res_N60_N77;
    i_N61_N78 = ycf_my_trap_state->i_N61_N78;
    ix_N62_N79 = ycf_my_trap_state->ix_N62_N79;
    jx_N63_N80 = ycf_my_trap_state->jx_N63_N80;
    elems_N64_N81 = ycf_my_trap_state->elems_N64_N81;
    sw_N65_N82 = ycf_my_trap_state->sw_N65_N82;
    hx_N66_N83 = ycf_my_trap_state->hx_N66_N83;
    val_N67_N84 = ycf_my_trap_state->val_N67_N84;
    tmp_N68_N85 = ycf_my_trap_state->tmp_N68_N85;
    ycf_sub_fun_trap_state_wb_N74 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N74;
    ycf_sub_fun_trap_state_wb_N75 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N75;
    ycf_sub_fun_trap_state_wb_N76 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N76;
    factory_N69_N86 = ycf_my_trap_state->factory_N69_N86;
    hxns_N70_N87 = ycf_my_trap_state->hxns_N70_N87;
    n_N71_N88 = ycf_my_trap_state->n_N71_N88;
    lvl_N72_N89 = ycf_my_trap_state->lvl_N72_N89;
    temp_memory_allocator_N73_N90 = ycf_my_trap_state->temp_memory_allocator_N73_N90;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N74 != NULL)
{     erts_qsort_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N74);
  }
}
{
  if(ycf_sub_fun_trap_state_wb_N75 != NULL)
{     hashmap_from_sorted_unique_array_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N75);
  }
}
{

    {
        if (tmp_N68_N85 != NULL) {
            /* Execution of this function got destroyed while yielding in
               the loop above */
            erts_free(temp_memory_allocator_N73_N90, (void *) tmp_N68_N85);
        }
    }}
{
  if(ycf_sub_fun_trap_state_wb_N76 != NULL)
{     hashmap_from_chunked_array_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N76);
  }
}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_sorted_unique_array_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array* ycf_my_trap_state = *ycf_trap_state;
return hashmap_from_sorted_unique_array_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->factory_N69_N86,ycf_my_trap_state->hxns_N70_N87,ycf_my_trap_state->n_N71_N88,ycf_my_trap_state->lvl_N72_N89,ycf_my_trap_state->temp_memory_allocator_N73_N90)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */


/* **Important Note**
 *
 * A yielding version of this function is generated with YCF. This
 * means that the code has to follow some restrictions. See note about
 * YCF near the top of the file for more information.
 */
static Eterm hashmap_from_sorted_unique_array_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,ErtsHeapFactory* factory_N69_N86,
                                              hxnode_t *hxns_N70_N87, Uint n_N71_N88, int lvl_N72_N89,
                                              ErtsAlcType_t temp_memory_allocator_N73_N90) {
    Eterm res_N60_N77;
    Uint i_N61_N78;
    Uint ix_N62_N79;
    Uint jx_N63_N80;
    Uint elems_N64_N81;
    Uint32 sw_N65_N82;
    Uint32 hx_N66_N83;
    Eterm val_N67_N84;
    hxnode_t *tmp_N68_N85;

void* ycf_sub_fun_trap_state_wb_N74;

void* ycf_sub_fun_trap_state_wb_N75;
void* ycf_sub_fun_trap_state_wb_N76;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    res_N60_N77 = ycf_my_trap_state->res_N60_N77;
    i_N61_N78 = ycf_my_trap_state->i_N61_N78;
    ix_N62_N79 = ycf_my_trap_state->ix_N62_N79;
    jx_N63_N80 = ycf_my_trap_state->jx_N63_N80;
    elems_N64_N81 = ycf_my_trap_state->elems_N64_N81;
    sw_N65_N82 = ycf_my_trap_state->sw_N65_N82;
    hx_N66_N83 = ycf_my_trap_state->hx_N66_N83;
    val_N67_N84 = ycf_my_trap_state->val_N67_N84;
    tmp_N68_N85 = ycf_my_trap_state->tmp_N68_N85;
    ycf_sub_fun_trap_state_wb_N74 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N74;
    ycf_sub_fun_trap_state_wb_N75 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N75;
    ycf_sub_fun_trap_state_wb_N76 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N76;
    factory_N69_N86 = ycf_my_trap_state->factory_N69_N86;
    hxns_N70_N87 = ycf_my_trap_state->hxns_N70_N87;
    n_N71_N88 = ycf_my_trap_state->n_N71_N88;
    lvl_N72_N89 = ycf_my_trap_state->lvl_N72_N89;
    temp_memory_allocator_N73_N90 = ycf_my_trap_state->temp_memory_allocator_N73_N90;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;
case 2: goto ycf_yield_location_label_2;
case 3: goto ycf_yield_location_label_3;
case 4: goto ycf_yield_location_label_4;
case 5: goto ycf_yield_location_label_5;
case 6: goto ycf_yield_location_label_6;
case 7: goto ycf_yield_location_label_7;
case 8: goto ycf_yield_location_label_8;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N74 = NULL;

ycf_sub_fun_trap_state_wb_N75 = NULL;

ycf_sub_fun_trap_state_wb_N76 = NULL;

}
    res_N60_N77 = NIL;
    tmp_N68_N85 = NULL;
    ASSERT(lvl_N72_N89 < 32);
    ix_N62_N79 = 0;
    elems_N64_N81 = 1;
    while (ix_N62_N79 < n_N71_N88 - 1)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 4;
  goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_4:;
}

}
    {
	if (hxns_N70_N87[ix_N62_N79].hx == hxns_N70_N87[ix_N62_N79+1].hx)
{
    {
	    jx_N63_N80 = ix_N62_N79 + 1;
	    while (jx_N63_N80 < n_N71_N88 && hxns_N70_N87[ix_N62_N79].hx == hxns_N70_N87[jx_N63_N80].hx)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 5;
  goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_5:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 6;
  goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_6:;
}

}
    { jx_N63_N80++; }

}

}
	    tmp_N68_N85 = (hxnode_t *)erts_alloc(temp_memory_allocator_N73_N90, ((jx_N63_N80 - ix_N62_N79)) * sizeof(hxnode_t));

	    for(i_N61_N78 = 0; i_N61_N78 < jx_N63_N80 - ix_N62_N79; i_N61_N78++)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 7;
  goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_7:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 8;
  goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_8:;
}

}
    {
		val_N67_N84 = hxns_N70_N87[i_N61_N78 + ix_N62_N79].val;
		hx_N66_N83  = hashmap_restore_hash(lvl_N72_N89 + 8, CAR(list_val(val_N67_N84)));
		swizzle32(sw_N65_N82,hx_N66_N83);
		tmp_N68_N85[i_N61_N78].hx   = sw_N65_N82;
		tmp_N68_N85[i_N61_N78].val  = val_N67_N84;
		tmp_N68_N85[i_N61_N78].i    = i_N61_N78;
		tmp_N68_N85[i_N61_N78].skip = 1;
	    }

}

}
{


ycf_sub_fun_trap_state_wb_N74 = NULL;
{
 erts_qsort_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N74,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,tmp_N68_N85, jx_N63_N80 - ix_N62_N79, sizeof(hxnode_t), hxnodecmp);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N74)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_1:;
    erts_qsort_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N74,
                            ycf_extra_context);
}


}
/* YCF Replaced special code */

}



	    hxns_N70_N87[ix_N62_N79].skip = jx_N63_N80 - ix_N62_N79;
{


ycf_sub_fun_trap_state_wb_N75 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_from_sorted_unique_array_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N75,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,factory_N69_N86, tmp_N68_N85, jx_N63_N80 - ix_N62_N79, lvl_N72_N89 + 8, temp_memory_allocator_N73_N90);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N75)){
   ycf_trap_location = 2;
   goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_2:;
   ycf_tmp_fun_call_tmp_var =  hashmap_from_sorted_unique_array_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N75,
                            ycf_extra_context);
}

	    hxns_N70_N87[ix_N62_N79].val = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}


	    erts_free(temp_memory_allocator_N73_N90, (void *) tmp_N68_N85);
            /* Memory management depend on the statement below */
            tmp_N68_N85 = NULL;
	    ix_N62_N79 = jx_N63_N80;
	    if (ix_N62_N79 < n_N71_N88)
{
    { elems_N64_N81++; }

}
	    continue;
	}

}
	hxns_N70_N87[ix_N62_N79].skip = 1;
	elems_N64_N81++;
	ix_N62_N79++;
    }

}
/* YCF Replaced special code */

{

ycf_sub_fun_trap_state_wb_N76 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_from_chunked_array_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N76,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,factory_N69_N86, hxns_N70_N87, elems_N64_N81, n_N71_N88, !lvl_N72_N89, temp_memory_allocator_N73_N90);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N76)){
   ycf_trap_location = 3;
   goto ycf_do_yield_label_hashmap_from_sorted_unique_array;
  ycf_yield_location_label_3:;
   ycf_tmp_fun_call_tmp_var =  hashmap_from_chunked_array_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N76,
                            ycf_extra_context);
}


    res_N60_N77 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}


    ERTS_FACTORY_HOLE_CHECK(factory_N69_N86);
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


    return res_N60_N77;
}

{
  struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array* ycf_my_trap_state;
  ycf_do_yield_label_hashmap_from_sorted_unique_array:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_hashmap_from_sorted_unique_array), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->res_N60_N77 = res_N60_N77;
    ycf_my_trap_state->i_N61_N78 = i_N61_N78;
    ycf_my_trap_state->ix_N62_N79 = ix_N62_N79;
    ycf_my_trap_state->jx_N63_N80 = jx_N63_N80;
    ycf_my_trap_state->elems_N64_N81 = elems_N64_N81;
    ycf_my_trap_state->sw_N65_N82 = sw_N65_N82;
    ycf_my_trap_state->hx_N66_N83 = hx_N66_N83;
    ycf_my_trap_state->val_N67_N84 = val_N67_N84;
    ycf_my_trap_state->tmp_N68_N85 = tmp_N68_N85;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N74 = ycf_sub_fun_trap_state_wb_N74;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N75 = ycf_sub_fun_trap_state_wb_N75;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N76 = ycf_sub_fun_trap_state_wb_N76;
    ycf_my_trap_state->factory_N69_N86 = factory_N69_N86;
    ycf_my_trap_state->hxns_N70_N87 = hxns_N70_N87;
    ycf_my_trap_state->n_N71_N88 = n_N71_N88;
    ycf_my_trap_state->lvl_N72_N89 = lvl_N72_N89;
    ycf_my_trap_state->temp_memory_allocator_N73_N90 = temp_memory_allocator_N73_N90;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   Eterm  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_hashmap_from_chunked_array {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Uint ix_N92_N115;
    Uint d_N93_N116;
    Uint dn_N94_N117;
    Uint dc_N95_N118;
    Uint slot_N96_N119;
    Uint elems_N97_N120;
    Uint32 v_N98_N121;
    Uint32 vp_N99_N122;
    Uint32 vn_N100_N123;
    Uint32 hdr_N101_N124;
    Uint bp_N102_N125;
    Uint sz_N103_N126;
    Eterm res_N104_N127;
    Eterm *hp_N105_N128;
    Eterm *nhp_N106_N129;
    Eterm stack_default_estack_N107_N130[16];    ErtsEStack stack_N108_N131;
	    int wat_N91_N132;ErtsHeapFactory *factory_N109_N133; hxnode_t *hxns_N110_N134; Uint n_N111_N135;
                                        Uint size_N112_N136; int is_root_N113_N137;
                                        ErtsAlcType_t temp_memory_allocator_N114_N138;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_chunked_array_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_hashmap_from_chunked_array* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Uint ix_N92_N115;
    Uint d_N93_N116;
    Uint dn_N94_N117;
    Uint dc_N95_N118;
    Uint slot_N96_N119;
    Uint elems_N97_N120;
    Uint32 v_N98_N121;
    Uint32 vp_N99_N122;
    Uint32 vn_N100_N123;
    Uint32 hdr_N101_N124;
    Uint bp_N102_N125;
    Uint sz_N103_N126;
    Eterm res_N104_N127;
    Eterm *hp_N105_N128;
    Eterm *nhp_N106_N129;
    Eterm stack_default_estack_N107_N130[16];    ErtsEStack stack_N108_N131;
	    int wat_N91_N132;ErtsHeapFactory *factory_N109_N133; hxnode_t *hxns_N110_N134; Uint n_N111_N135;
                                        Uint size_N112_N136; int is_root_N113_N137;
                                        ErtsAlcType_t temp_memory_allocator_N114_N138;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    ix_N92_N115 = ycf_my_trap_state->ix_N92_N115;
    d_N93_N116 = ycf_my_trap_state->d_N93_N116;
    dn_N94_N117 = ycf_my_trap_state->dn_N94_N117;
    dc_N95_N118 = ycf_my_trap_state->dc_N95_N118;
    slot_N96_N119 = ycf_my_trap_state->slot_N96_N119;
    elems_N97_N120 = ycf_my_trap_state->elems_N97_N120;
    v_N98_N121 = ycf_my_trap_state->v_N98_N121;
    vp_N99_N122 = ycf_my_trap_state->vp_N99_N122;
    vn_N100_N123 = ycf_my_trap_state->vn_N100_N123;
    hdr_N101_N124 = ycf_my_trap_state->hdr_N101_N124;
    bp_N102_N125 = ycf_my_trap_state->bp_N102_N125;
    sz_N103_N126 = ycf_my_trap_state->sz_N103_N126;
    res_N104_N127 = ycf_my_trap_state->res_N104_N127;
    hp_N105_N128 = ycf_my_trap_state->hp_N105_N128;
    nhp_N106_N129 = ycf_my_trap_state->nhp_N106_N129;
    memcpy(stack_default_estack_N107_N130, ycf_my_trap_state->stack_default_estack_N107_N130, 16 *  sizeof(
    Eterm));
    stack_N108_N131 = ycf_my_trap_state->stack_N108_N131;
    wat_N91_N132 = ycf_my_trap_state->wat_N91_N132;
    factory_N109_N133 = ycf_my_trap_state->factory_N109_N133;
    hxns_N110_N134 = ycf_my_trap_state->hxns_N110_N134;
    n_N111_N135 = ycf_my_trap_state->n_N111_N135;
    size_N112_N136 = ycf_my_trap_state->size_N112_N136;
    is_root_N113_N137 = ycf_my_trap_state->is_root_N113_N137;
    temp_memory_allocator_N114_N138 = ycf_my_trap_state->temp_memory_allocator_N114_N138;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{

    {
        DESTROY_ESTACK_EXPLICIT_DEFAULT_ARRAY(stack_N108_N131, stack_default_estack_N107_N130);
    }}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_chunked_array_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_hashmap_from_chunked_array* ycf_my_trap_state = *ycf_trap_state;
return hashmap_from_chunked_array_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->factory_N109_N133,ycf_my_trap_state->hxns_N110_N134,ycf_my_trap_state->n_N111_N135,ycf_my_trap_state->size_N112_N136,ycf_my_trap_state->is_root_N113_N137,ycf_my_trap_state->temp_memory_allocator_N114_N138)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */

/* **Important Note**
 *
 * A yielding version of this function is generated with YCF. This
 * means that the code has to follow some restrictions. See note about
 * YCF near the top of the file for more information.
 */
static Eterm hashmap_from_chunked_array_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,ErtsHeapFactory *factory_N109_N133, hxnode_t *hxns_N110_N134, Uint n_N111_N135,
                                        Uint size_N112_N136, int is_root_N113_N137,
                                        ErtsAlcType_t temp_memory_allocator_N114_N138) {
    Uint ix_N92_N115;
    Uint d_N93_N116;
    Uint dn_N94_N117;
    Uint dc_N95_N118;
    Uint slot_N96_N119;
    Uint elems_N97_N120;
    Uint32 v_N98_N121;
    Uint32 vp_N99_N122;
    Uint32 vn_N100_N123;
    Uint32 hdr_N101_N124;
    Uint bp_N102_N125;
    Uint sz_N103_N126;
    Eterm res_N104_N127;
    Eterm *hp_N105_N128;
    Eterm *nhp_N106_N129;
    Eterm stack_default_estack_N107_N130[16];    ErtsEStack stack_N108_N131;
	    int wat_N91_N132;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_hashmap_from_chunked_array* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    ix_N92_N115 = ycf_my_trap_state->ix_N92_N115;
    d_N93_N116 = ycf_my_trap_state->d_N93_N116;
    dn_N94_N117 = ycf_my_trap_state->dn_N94_N117;
    dc_N95_N118 = ycf_my_trap_state->dc_N95_N118;
    slot_N96_N119 = ycf_my_trap_state->slot_N96_N119;
    elems_N97_N120 = ycf_my_trap_state->elems_N97_N120;
    v_N98_N121 = ycf_my_trap_state->v_N98_N121;
    vp_N99_N122 = ycf_my_trap_state->vp_N99_N122;
    vn_N100_N123 = ycf_my_trap_state->vn_N100_N123;
    hdr_N101_N124 = ycf_my_trap_state->hdr_N101_N124;
    bp_N102_N125 = ycf_my_trap_state->bp_N102_N125;
    sz_N103_N126 = ycf_my_trap_state->sz_N103_N126;
    res_N104_N127 = ycf_my_trap_state->res_N104_N127;
    hp_N105_N128 = ycf_my_trap_state->hp_N105_N128;
    nhp_N106_N129 = ycf_my_trap_state->nhp_N106_N129;
    memcpy(stack_default_estack_N107_N130, ycf_my_trap_state->stack_default_estack_N107_N130, 16 *  sizeof(
    Eterm));
    stack_N108_N131 = ycf_my_trap_state->stack_N108_N131;
    wat_N91_N132 = ycf_my_trap_state->wat_N91_N132;
    factory_N109_N133 = ycf_my_trap_state->factory_N109_N133;
    hxns_N110_N134 = ycf_my_trap_state->hxns_N110_N134;
    n_N111_N135 = ycf_my_trap_state->n_N111_N135;
    size_N112_N136 = ycf_my_trap_state->size_N112_N136;
    is_root_N113_N137 = ycf_my_trap_state->is_root_N113_N137;
    temp_memory_allocator_N114_N138 = ycf_my_trap_state->temp_memory_allocator_N114_N138;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;
case 2: goto ycf_yield_location_label_2;
case 3: goto ycf_yield_location_label_3;
case 4: goto ycf_yield_location_label_4;
case 5: goto ycf_yield_location_label_5;
case 6: goto ycf_yield_location_label_6;
case 7: goto ycf_yield_location_label_7;
case 8: goto ycf_yield_location_label_8;
case 9: goto ycf_yield_location_label_9;
case 10: goto ycf_yield_location_label_10;
case 11: goto ycf_yield_location_label_11;
case 12: goto ycf_yield_location_label_12;
case 13: goto ycf_yield_location_label_13;
case 14: goto ycf_yield_location_label_14;
case 15: goto ycf_yield_location_label_15;
case 16: goto ycf_yield_location_label_16;
case 17: goto ycf_yield_location_label_17;
case 18: goto ycf_yield_location_label_18;
case 19: goto ycf_yield_location_label_19;

}
  }
}
{

}
    res_N104_N127 = NIL;
    hp_N105_N128 = NULL;
    nhp_N106_N129 = NULL;
#if DEF_ESTACK_SIZE != (16)
    #error "The macro DEF_ESTACK_SIZE has changed from 16 (need to change constant above)"
    /* We cannot use "Eterm stack_default_estack[DEF_ESTACK_SIZE];"
       because macros are not expanded before the code is passed to
       YCF, and YCF needs to know the size of the array */
#endif

{

/* moved declaration (stack)*/

}
    stack_N108_N131 = ESTACK_DEFAULT_VALUE(stack_default_estack_N107_N130, temp_memory_allocator_N114_N138);
/* YCF Replaced special code */

/* YCF Replaced special code */


    /* if we get here with only one element then
     * we have eight levels of collisions
     */

    if (n_N111_N135 == 1)
{
    {
	res_N104_N127 = hxns_N110_N134[0].val;
	v_N98_N121   = hxns_N110_N134[0].hx;
	for (d_N93_N116 = 7; d_N93_N116 > 0; d_N93_N116--)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 1;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_1:;
}

}
    {
	    slot_N96_N119  = maskval(v_N98_N121,d_N93_N116);
	    hp_N105_N128    = erts_produce_heap(factory_N109_N133, HAMT_NODE_BITMAP_SZ(1), HALLOC_EXTRA);
	    hp_N105_N128[0] = MAP_HEADER_HAMT_NODE_BITMAP(1 << slot_N96_N119);
	    hp_N105_N128[1] = res_N104_N127;
	    res_N104_N127   = make_hashmap(hp_N105_N128);
	}

}

	slot_N96_N119  = maskval(v_N98_N121,0);
	hp_N105_N128    = erts_produce_heap(factory_N109_N133, (is_root_N113_N137 ? 3 : 2), 0);

	if (is_root_N113_N137)
{
    {
	    hp_N105_N128[0] = MAP_HEADER_HAMT_HEAD_BITMAP(1 << slot_N96_N119);
	    hp_N105_N128[1] = size_N112_N136;
	    hp_N105_N128[2] = res_N104_N127;
	}

} else
{
    {
	    hp_N105_N128[0] = MAP_HEADER_HAMT_NODE_BITMAP(1 << slot_N96_N119);
	    hp_N105_N128[1] = res_N104_N127;
	}

}
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

	return make_hashmap(hp_N105_N128);
}
    }

}

    /* push initial nodes on the stack,
     * this is the starting depth */

    ix_N92_N115 = 0;
    d_N93_N116  = 0;
    vp_N99_N122 = hxns_N110_N134[ix_N92_N115].hx;
    v_N98_N121  = hxns_N110_N134[ix_N92_N115 + hxns_N110_N134[ix_N92_N115].skip].hx;

    ASSERT(vp_N99_N122 > v_N98_N121);
    slot_N96_N119 = maskval(vp_N99_N122,d_N93_N116);

    while(slot_N96_N119 == maskval(v_N98_N121,d_N93_N116))
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 2;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_2:;
}

}
    {
	ESTACK_PUSH(stack_N108_N131, 1 << slot_N96_N119);
	d_N93_N116++;
	slot_N96_N119 = maskval(vp_N99_N122,d_N93_N116);
    }

}

    res_N104_N127 = hxns_N110_N134[ix_N92_N115].val;

    if (hxns_N110_N134[ix_N92_N115].skip > 1)
{
    {
	dc_N95_N118 = 7;
	/* build collision nodes */
	while (dc_N95_N118 > d_N93_N116)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 3;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_3:;
}

}
    {
	    hp_N105_N128    = erts_produce_heap(factory_N109_N133, HAMT_NODE_BITMAP_SZ(1), HALLOC_EXTRA);
	    hp_N105_N128[0] = MAP_HEADER_HAMT_NODE_BITMAP(1 << maskval(vp_N99_N122,dc_N95_N118));
	    hp_N105_N128[1] = res_N104_N127;
	    res_N104_N127   = make_hashmap(hp_N105_N128);
	    dc_N95_N118--;
	}

}
    }

}

    ESTACK_PUSH2(stack_N108_N131,res_N104_N127,1 << slot_N96_N119);

    /* all of the other nodes .. */
    elems_N97_N120 = n_N111_N135 - 2; /* remove first and last elements */
    while(elems_N97_N120--)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 4;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_4:;
}

}
    {
	hdr_N101_N124 = ESTACK_POP(stack_N108_N131);
	ix_N92_N115  = ix_N92_N115 + hxns_N110_N134[ix_N92_N115].skip;

	/* determine if node or subtree should be built by looking
	 * at the next value. */

	vn_N100_N123 = hxns_N110_N134[ix_N92_N115 + hxns_N110_N134[ix_N92_N115].skip].hx;
	dn_N94_N117 = cdepth(v_N98_N121,vn_N100_N123);
	ASSERT(v_N98_N121 > vn_N100_N123);

	res_N104_N127 = hxns_N110_N134[ix_N92_N115].val;

	if (hxns_N110_N134[ix_N92_N115].skip > 1)
{
    {
	    wat_N91_N132 = (d_N93_N116 > dn_N94_N117) ? d_N93_N116 : dn_N94_N117;
	    dc_N95_N118 = 7;
	    /* build collision nodes */
	    while (dc_N95_N118 > wat_N91_N132)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 5;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_5:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 6;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_6:;
}

}
    {
		hp_N105_N128    = erts_produce_heap(factory_N109_N133, HAMT_NODE_BITMAP_SZ(1), HALLOC_EXTRA);
		hp_N105_N128[0] = MAP_HEADER_HAMT_NODE_BITMAP(1 << maskval(v_N98_N121,dc_N95_N118));
		hp_N105_N128[1] = res_N104_N127;
		res_N104_N127   = make_hashmap(hp_N105_N128);
		dc_N95_N118--;
	    }

}

}
	}

}

	/* next depth is higher (implies collision) */
	if (d_N93_N116 < dn_N94_N117)
{
    {
	    /* hdr is the popped one initially */
	    while(d_N93_N116 < dn_N94_N117)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 7;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_7:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 8;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_8:;
}

}
    {
		slot_N96_N119 = maskval(v_N98_N121, d_N93_N116);
		bp_N102_N125   = 1 << slot_N96_N119;
		ESTACK_PUSH(stack_N108_N131, hdr_N101_N124 | bp_N102_N125);
		d_N93_N116++;
		hdr_N101_N124 = 0; /* clear hdr for all other collisions */
	    }

}

}

	    slot_N96_N119 = maskval(v_N98_N121, d_N93_N116);
	    bp_N102_N125   = 1 << slot_N96_N119;
	    /* no more collisions */
            ESTACK_PUSH2(stack_N108_N131,res_N104_N127,bp_N102_N125);
	}

} else
{
{
    if (d_N93_N116 == dn_N94_N117)
{
    {
	    /* no collisions at all */
	    slot_N96_N119 = maskval(v_N98_N121, d_N93_N116);
	    bp_N102_N125   = 1 << slot_N96_N119;
            ESTACK_PUSH2(stack_N108_N131,res_N104_N127,hdr_N101_N124 | bp_N102_N125);
	}

} else
{
    {
	    /* dn < n, we have a drop and we are done
	     * build nodes and subtree */
	    while (dn_N94_N117 != d_N93_N116)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 9;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_9:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 10;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_10:;
}

}
    {
		slot_N96_N119  = maskval(v_N98_N121, d_N93_N116);
		bp_N102_N125    = 1 << slot_N96_N119;
		/* OR bitposition before sz calculation to handle
		 * redundant collisions */
		hdr_N101_N124  |= bp_N102_N125;
		sz_N103_N126    = hashmap_bitcount(hdr_N101_N124);
		hp_N105_N128    = erts_produce_heap(factory_N109_N133, HAMT_NODE_BITMAP_SZ(sz_N103_N126), HALLOC_EXTRA);
		nhp_N106_N129   = hp_N105_N128;
		*hp_N105_N128++ = MAP_HEADER_HAMT_NODE_BITMAP(hdr_N101_N124);
		*hp_N105_N128++ = res_N104_N127; sz_N103_N126--;
		while (sz_N103_N126--)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 11;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_11:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 12;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_12:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 13;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_13:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 14;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_14:;
}

}
    { *hp_N105_N128++ = ESTACK_POP(stack_N108_N131); }

}

}

}

}
		ASSERT((hp_N105_N128 - nhp_N106_N129) < 18);
		res_N104_N127 = make_hashmap(nhp_N106_N129);

		/* we need to pop the next hdr and push if we don't need it */

		hdr_N101_N124 = ESTACK_POP(stack_N108_N131);
		d_N93_N116--;
	    }

}

}
            ESTACK_PUSH2(stack_N108_N131,res_N104_N127,hdr_N101_N124);
	}

}
}

}

	vp_N99_N122 = v_N98_N121;
	v_N98_N121  = vn_N100_N123;
	d_N93_N116  = dn_N94_N117;
	ERTS_FACTORY_HOLE_CHECK(factory_N109_N133);
    }

}

    /* v and vp are reused from above */
    dn_N94_N117  = cdepth(vp_N99_N122,v_N98_N121);
    ix_N92_N115  = ix_N92_N115 + hxns_N110_N134[ix_N92_N115].skip;
    res_N104_N127 = hxns_N110_N134[ix_N92_N115].val;

    if (hxns_N110_N134[ix_N92_N115].skip > 1)
{
    {
	dc_N95_N118 = 7;
	/* build collision nodes */
	while (dc_N95_N118 > dn_N94_N117)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 15;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_15:;
}

}
    {
	    hp_N105_N128    = erts_produce_heap(factory_N109_N133, HAMT_NODE_BITMAP_SZ(1), HALLOC_EXTRA);
	    hp_N105_N128[0] = MAP_HEADER_HAMT_NODE_BITMAP(1 << maskval(v_N98_N121,dc_N95_N118));
	    hp_N105_N128[1] = res_N104_N127;
	    res_N104_N127   = make_hashmap(hp_N105_N128);
	    dc_N95_N118--;
	}

}
    }

}

    hdr_N101_N124 = ESTACK_POP(stack_N108_N131);
    /* pop remaining subtree if any */
    while (dn_N94_N117)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 16;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_16:;
}

}
    {
	slot_N96_N119  = maskval(v_N98_N121, dn_N94_N117);
	bp_N102_N125    = 1 << slot_N96_N119;
	/* OR bitposition before sz calculation to handle
	 * redundant collisions */
	hdr_N101_N124  |= bp_N102_N125;
	sz_N103_N126    = hashmap_bitcount(hdr_N101_N124);
	hp_N105_N128    = erts_produce_heap(factory_N109_N133, HAMT_NODE_BITMAP_SZ(sz_N103_N126), HALLOC_EXTRA);
	nhp_N106_N129   = hp_N105_N128;
	*hp_N105_N128++ = MAP_HEADER_HAMT_NODE_BITMAP(hdr_N101_N124);
	*hp_N105_N128++ = res_N104_N127; sz_N103_N126--;

        ASSERT(ESTACK_COUNT(stack_N108_N131) > sz_N103_N126);

	while (sz_N103_N126--)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 17;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_17:;
}

}

{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 18;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_18:;
}

}
    { *hp_N105_N128++ = ESTACK_POP(stack_N108_N131); }

}

}
	res_N104_N127 = make_hashmap(nhp_N106_N129);
	hdr_N101_N124 = ESTACK_POP(stack_N108_N131);
	dn_N94_N117--;
    }

}

    /* and finally the root .. */

    slot_N96_N119  = maskval(v_N98_N121, dn_N94_N117);
    bp_N102_N125    = 1 << slot_N96_N119;
    hdr_N101_N124  |= bp_N102_N125;
    sz_N103_N126    = hashmap_bitcount(hdr_N101_N124);
    hp_N105_N128    = erts_produce_heap(factory_N109_N133, sz_N103_N126 + /* hdr + item */ (is_root_N113_N137 ? 2 : 1), 0);
    nhp_N106_N129   = hp_N105_N128;

    if (is_root_N113_N137)
{
    {
	*hp_N105_N128++ = (hdr_N101_N124 == 0xffff) ? MAP_HEADER_HAMT_HEAD_ARRAY : MAP_HEADER_HAMT_HEAD_BITMAP(hdr_N101_N124);
	*hp_N105_N128++ = size_N112_N136;
    }

} else
{
    {
	*hp_N105_N128++ = MAP_HEADER_HAMT_NODE_BITMAP(hdr_N101_N124);
    }

}

    *hp_N105_N128++ = res_N104_N127; sz_N103_N126--;
    while (sz_N103_N126--)
{
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 19;
  goto ycf_do_yield_label_hashmap_from_chunked_array;
  ycf_yield_location_label_19:;
}

}
    { *hp_N105_N128++ = ESTACK_POP(stack_N108_N131); }

}

    res_N104_N127 = make_hashmap(nhp_N106_N129);

    ASSERT(ESTACK_COUNT(stack_N108_N131) == 0);
    DESTROY_ESTACK_EXPLICIT_DEFAULT_ARRAY(stack_N108_N131, stack_default_estack_N107_N130);
    ERTS_FACTORY_HOLE_CHECK(factory_N109_N133);
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

    return res_N104_N127;
}

{
  struct gen_ycf_trap_state_for_hashmap_from_chunked_array* ycf_my_trap_state;
  ycf_do_yield_label_hashmap_from_chunked_array:;

    {
        ENSURE_ESTACK_HEAP_STACK_ARRAY(stack_N108_N131, stack_default_estack_N107_N130);
    }

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_hashmap_from_chunked_array), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->ix_N92_N115 = ix_N92_N115;
    ycf_my_trap_state->d_N93_N116 = d_N93_N116;
    ycf_my_trap_state->dn_N94_N117 = dn_N94_N117;
    ycf_my_trap_state->dc_N95_N118 = dc_N95_N118;
    ycf_my_trap_state->slot_N96_N119 = slot_N96_N119;
    ycf_my_trap_state->elems_N97_N120 = elems_N97_N120;
    ycf_my_trap_state->v_N98_N121 = v_N98_N121;
    ycf_my_trap_state->vp_N99_N122 = vp_N99_N122;
    ycf_my_trap_state->vn_N100_N123 = vn_N100_N123;
    ycf_my_trap_state->hdr_N101_N124 = hdr_N101_N124;
    ycf_my_trap_state->bp_N102_N125 = bp_N102_N125;
    ycf_my_trap_state->sz_N103_N126 = sz_N103_N126;
    ycf_my_trap_state->res_N104_N127 = res_N104_N127;
    ycf_my_trap_state->hp_N105_N128 = hp_N105_N128;
    ycf_my_trap_state->nhp_N106_N129 = nhp_N106_N129;
    memcpy(ycf_my_trap_state->stack_default_estack_N107_N130, stack_default_estack_N107_N130, 16 *  sizeof(
    Eterm));
    ycf_my_trap_state->stack_N108_N131 = stack_N108_N131;
    ycf_my_trap_state->wat_N91_N132 = wat_N91_N132;
    ycf_my_trap_state->factory_N109_N133 = factory_N109_N133;
    ycf_my_trap_state->hxns_N110_N134 = hxns_N110_N134;
    ycf_my_trap_state->n_N111_N135 = n_N111_N135;
    ycf_my_trap_state->size_N112_N136 = size_N112_N136;
    ycf_my_trap_state->is_root_N113_N137 = is_root_N113_N137;
    ycf_my_trap_state->temp_memory_allocator_N114_N138 = temp_memory_allocator_N114_N138;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   Eterm  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_maps_keys_1_helper {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm map_N145_N149;
	Eterm *hp_N139_N150;
        Eterm *ks_N140_N151;
        Eterm res_N141_N152;
	flatmap_t *mp_N142_N153;
	Uint n_N143_N154;
        /* YCF cannot handle function calls as return expression */
        BIF_RETTYPE res_N144_N155;

void* ycf_sub_fun_trap_state_wb_N148;Process* p_N146_N156; Eterm* bif_args_N147_N157;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_keys_1_helper_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_maps_keys_1_helper* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm map_N145_N149;
	Eterm *hp_N139_N150;
        Eterm *ks_N140_N151;
        Eterm res_N141_N152;
	flatmap_t *mp_N142_N153;
	Uint n_N143_N154;
        /* YCF cannot handle function calls as return expression */
        BIF_RETTYPE res_N144_N155;

void* ycf_sub_fun_trap_state_wb_N148;Process* p_N146_N156; Eterm* bif_args_N147_N157;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    map_N145_N149 = ycf_my_trap_state->map_N145_N149;
    hp_N139_N150 = ycf_my_trap_state->hp_N139_N150;
    ks_N140_N151 = ycf_my_trap_state->ks_N140_N151;
    res_N141_N152 = ycf_my_trap_state->res_N141_N152;
    mp_N142_N153 = ycf_my_trap_state->mp_N142_N153;
    n_N143_N154 = ycf_my_trap_state->n_N143_N154;
    res_N144_N155 = ycf_my_trap_state->res_N144_N155;
    ycf_sub_fun_trap_state_wb_N148 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N148;
    p_N146_N156 = ycf_my_trap_state->p_N146_N156;
    bif_args_N147_N157 = ycf_my_trap_state->bif_args_N147_N157;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N148 != NULL)
{     hashmap_keys_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N148);
  }
}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_keys_1_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_maps_keys_1_helper* ycf_my_trap_state = *ycf_trap_state;
return maps_keys_1_helper_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N146_N156,ycf_my_trap_state->bif_args_N147_N157)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static BIF_RETTYPE maps_keys_1_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N146_N156, Eterm* bif_args_N147_N157) {
    Eterm map_N145_N149;
	Eterm *hp_N139_N150;
        Eterm *ks_N140_N151;
        Eterm res_N141_N152;
	flatmap_t *mp_N142_N153;
	Uint n_N143_N154;
        /* YCF cannot handle function calls as return expression */
        BIF_RETTYPE res_N144_N155;

void* ycf_sub_fun_trap_state_wb_N148;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_maps_keys_1_helper* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    map_N145_N149 = ycf_my_trap_state->map_N145_N149;
    hp_N139_N150 = ycf_my_trap_state->hp_N139_N150;
    ks_N140_N151 = ycf_my_trap_state->ks_N140_N151;
    res_N141_N152 = ycf_my_trap_state->res_N141_N152;
    mp_N142_N153 = ycf_my_trap_state->mp_N142_N153;
    n_N143_N154 = ycf_my_trap_state->n_N143_N154;
    res_N144_N155 = ycf_my_trap_state->res_N144_N155;
    ycf_sub_fun_trap_state_wb_N148 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N148;
    p_N146_N156 = ycf_my_trap_state->p_N146_N156;
    bif_args_N147_N157 = ycf_my_trap_state->bif_args_N147_N157;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N148 = NULL;

}
    map_N145_N149 = bif_args_N147_N157[0];
    if (is_flatmap(map_N145_N149))
{
    {
        res_N141_N152 = NIL;

	mp_N142_N153  = (flatmap_t*)flatmap_val(map_N145_N149);
	n_N143_N154   = flatmap_get_size(mp_N142_N153);

	if (n_N143_N154 == 0)
{
{
   
	    BIF_RET(res_N141_N152);
}

}

	hp_N139_N150  = HAlloc(p_N146_N156, (2 * n_N143_N154));
	ks_N140_N151  = flatmap_get_keys(mp_N142_N153);

	while(n_N143_N154--)
{
    {
	    res_N141_N152 = CONS(hp_N139_N150, ks_N140_N151[n_N143_N154], res_N141_N152); hp_N139_N150 += 2;
	}

}
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


	return res_N141_N152;
}
    }

} else
{
{
    if (is_hashmap(bif_args_N147_N157[0]))
{
    {
{


ycf_sub_fun_trap_state_wb_N148 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_keys_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N148,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,p_N146_N156, map_N145_N149);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N148)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_maps_keys_1_helper;
  ycf_yield_location_label_1:;
   ycf_tmp_fun_call_tmp_var =  hashmap_keys_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N148,
                            ycf_extra_context);
}

        /* YCF cannot handle function calls as return expression */
        res_N144_N155 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}

{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


	return res_N144_N155;
}
    }

}
}

}
    p_N146_N156->fvalue = map_N145_N149;
    (p_N146_N156)->freason = BADMAP;
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

    return THE_NON_VALUE;
}

{
  struct gen_ycf_trap_state_for_maps_keys_1_helper* ycf_my_trap_state;
  ycf_do_yield_label_maps_keys_1_helper:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_maps_keys_1_helper), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->map_N145_N149 = map_N145_N149;
    ycf_my_trap_state->hp_N139_N150 = hp_N139_N150;
    ycf_my_trap_state->ks_N140_N151 = ks_N140_N151;
    ycf_my_trap_state->res_N141_N152 = res_N141_N152;
    ycf_my_trap_state->mp_N142_N153 = mp_N142_N153;
    ycf_my_trap_state->n_N143_N154 = n_N143_N154;
    ycf_my_trap_state->res_N144_N155 = res_N144_N155;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N148 = ycf_sub_fun_trap_state_wb_N148;
    ycf_my_trap_state->p_N146_N156 = p_N146_N156;
    ycf_my_trap_state->bif_args_N147_N157 = bif_args_N147_N157;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   BIF_RETTYPE  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_maps_values_1_helper {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm map_N164_N168;
        Eterm *hp_N158_N169;
        Eterm *vs_N159_N170;
        Eterm res_N160_N171;
	flatmap_t *mp_N161_N172;
	Uint n_N162_N173;
        /* YCF cannot handle function calls as return expression */
        BIF_RETTYPE res_N163_N174;

void* ycf_sub_fun_trap_state_wb_N167;Process* p_N165_N175; Eterm* bif_args_N166_N176;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_values_1_helper_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_maps_values_1_helper* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm map_N164_N168;
        Eterm *hp_N158_N169;
        Eterm *vs_N159_N170;
        Eterm res_N160_N171;
	flatmap_t *mp_N161_N172;
	Uint n_N162_N173;
        /* YCF cannot handle function calls as return expression */
        BIF_RETTYPE res_N163_N174;

void* ycf_sub_fun_trap_state_wb_N167;Process* p_N165_N175; Eterm* bif_args_N166_N176;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    map_N164_N168 = ycf_my_trap_state->map_N164_N168;
    hp_N158_N169 = ycf_my_trap_state->hp_N158_N169;
    vs_N159_N170 = ycf_my_trap_state->vs_N159_N170;
    res_N160_N171 = ycf_my_trap_state->res_N160_N171;
    mp_N161_N172 = ycf_my_trap_state->mp_N161_N172;
    n_N162_N173 = ycf_my_trap_state->n_N162_N173;
    res_N163_N174 = ycf_my_trap_state->res_N163_N174;
    ycf_sub_fun_trap_state_wb_N167 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N167;
    p_N165_N175 = ycf_my_trap_state->p_N165_N175;
    bif_args_N166_N176 = ycf_my_trap_state->bif_args_N166_N176;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N167 != NULL)
{     hashmap_values_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N167);
  }
}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_values_1_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_maps_values_1_helper* ycf_my_trap_state = *ycf_trap_state;
return maps_values_1_helper_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N165_N175,ycf_my_trap_state->bif_args_N166_N176)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static BIF_RETTYPE maps_values_1_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N165_N175, Eterm* bif_args_N166_N176) {
    Eterm map_N164_N168;
        Eterm *hp_N158_N169;
        Eterm *vs_N159_N170;
        Eterm res_N160_N171;
	flatmap_t *mp_N161_N172;
	Uint n_N162_N173;
        /* YCF cannot handle function calls as return expression */
        BIF_RETTYPE res_N163_N174;

void* ycf_sub_fun_trap_state_wb_N167;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_maps_values_1_helper* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    map_N164_N168 = ycf_my_trap_state->map_N164_N168;
    hp_N158_N169 = ycf_my_trap_state->hp_N158_N169;
    vs_N159_N170 = ycf_my_trap_state->vs_N159_N170;
    res_N160_N171 = ycf_my_trap_state->res_N160_N171;
    mp_N161_N172 = ycf_my_trap_state->mp_N161_N172;
    n_N162_N173 = ycf_my_trap_state->n_N162_N173;
    res_N163_N174 = ycf_my_trap_state->res_N163_N174;
    ycf_sub_fun_trap_state_wb_N167 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N167;
    p_N165_N175 = ycf_my_trap_state->p_N165_N175;
    bif_args_N166_N176 = ycf_my_trap_state->bif_args_N166_N176;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N167 = NULL;

}
    map_N164_N168 = bif_args_N166_N176[0];
    if (is_flatmap(map_N164_N168))
{
    {
        res_N160_N171 = NIL;

	mp_N161_N172  = (flatmap_t*)flatmap_val(map_N164_N168);
	n_N162_N173   = flatmap_get_size(mp_N161_N172);

	if (n_N162_N173 == 0)
{
{
   
	    BIF_RET(res_N160_N171);
}

}

	hp_N158_N169  = HAlloc(p_N165_N175, (2 * n_N162_N173));
	vs_N159_N170  = flatmap_get_values(mp_N161_N172);

	while(n_N162_N173--)
{
    {
	    res_N160_N171 = CONS(hp_N158_N169, vs_N159_N170[n_N162_N173], res_N160_N171); hp_N158_N169 += 2;
	}

}
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


	return res_N160_N171;
}
    }

} else
{
{
    if (is_hashmap(map_N164_N168))
{
    {
{


ycf_sub_fun_trap_state_wb_N167 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_values_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N167,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,p_N165_N175, map_N164_N168);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N167)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_maps_values_1_helper;
  ycf_yield_location_label_1:;
   ycf_tmp_fun_call_tmp_var =  hashmap_values_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N167,
                            ycf_extra_context);
}

        /* YCF cannot handle function calls as return expression */
        res_N163_N174 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}

{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


	return res_N163_N174;
}
    }

}
}

}
    p_N165_N175->fvalue = map_N164_N168;
    (p_N165_N175)->freason = BADMAP;
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

    return THE_NON_VALUE;
}

{
  struct gen_ycf_trap_state_for_maps_values_1_helper* ycf_my_trap_state;
  ycf_do_yield_label_maps_values_1_helper:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_maps_values_1_helper), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->map_N164_N168 = map_N164_N168;
    ycf_my_trap_state->hp_N158_N169 = hp_N158_N169;
    ycf_my_trap_state->vs_N159_N170 = vs_N159_N170;
    ycf_my_trap_state->res_N160_N171 = res_N160_N171;
    ycf_my_trap_state->mp_N161_N172 = mp_N161_N172;
    ycf_my_trap_state->n_N162_N173 = n_N162_N173;
    ycf_my_trap_state->res_N163_N174 = res_N163_N174;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N167 = ycf_sub_fun_trap_state_wb_N167;
    ycf_my_trap_state->p_N165_N175 = p_N165_N175;
    ycf_my_trap_state->bif_args_N166_N176 = bif_args_N166_N176;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   BIF_RETTYPE  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_maps_from_keys_2_helper {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm list_N177_N185;
    Eterm value_N178_N186;
    Eterm item_N179_N187;
    Eterm res_N180_N188;
    Uint  size_N181_N189;

void* ycf_sub_fun_trap_state_wb_N184;Process* p_N182_N190; Eterm* bif_args_N183_N191;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_from_keys_2_helper_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_maps_from_keys_2_helper* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm list_N177_N185;
    Eterm value_N178_N186;
    Eterm item_N179_N187;
    Eterm res_N180_N188;
    Uint  size_N181_N189;

void* ycf_sub_fun_trap_state_wb_N184;Process* p_N182_N190; Eterm* bif_args_N183_N191;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    list_N177_N185 = ycf_my_trap_state->list_N177_N185;
    value_N178_N186 = ycf_my_trap_state->value_N178_N186;
    item_N179_N187 = ycf_my_trap_state->item_N179_N187;
    res_N180_N188 = ycf_my_trap_state->res_N180_N188;
    size_N181_N189 = ycf_my_trap_state->size_N181_N189;
    ycf_sub_fun_trap_state_wb_N184 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N184;
    p_N182_N190 = ycf_my_trap_state->p_N182_N190;
    bif_args_N183_N191 = ycf_my_trap_state->bif_args_N183_N191;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N184 != NULL)
{     hashmap_from_validated_list_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N184);
  }
}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_from_keys_2_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_maps_from_keys_2_helper* ycf_my_trap_state = *ycf_trap_state;
return maps_from_keys_2_helper_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N182_N190,ycf_my_trap_state->bif_args_N183_N191)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static BIF_RETTYPE maps_from_keys_2_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N182_N190, Eterm* bif_args_N183_N191) {
    Eterm list_N177_N185;
    Eterm value_N178_N186;
    Eterm item_N179_N187;
    Eterm res_N180_N188;
    Uint  size_N181_N189;

void* ycf_sub_fun_trap_state_wb_N184;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_maps_from_keys_2_helper* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    list_N177_N185 = ycf_my_trap_state->list_N177_N185;
    value_N178_N186 = ycf_my_trap_state->value_N178_N186;
    item_N179_N187 = ycf_my_trap_state->item_N179_N187;
    res_N180_N188 = ycf_my_trap_state->res_N180_N188;
    size_N181_N189 = ycf_my_trap_state->size_N181_N189;
    ycf_sub_fun_trap_state_wb_N184 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N184;
    p_N182_N190 = ycf_my_trap_state->p_N182_N190;
    bif_args_N183_N191 = ycf_my_trap_state->bif_args_N183_N191;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;
case 2: goto ycf_yield_location_label_2;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N184 = NULL;

}
    list_N177_N185 = bif_args_N183_N191[0];
    value_N178_N186 = bif_args_N183_N191[1];
    item_N179_N187 = list_N177_N185;
    size_N181_N189 = 0;
    if (is_list(item_N179_N187) || is_nil(item_N179_N187))
{
    {
        /* Calculate size and check validity */
        while(is_list(item_N179_N187))
{
    {
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 2;
  goto ycf_do_yield_label_maps_from_keys_2_helper;
  ycf_yield_location_label_2:;
}

}
            size_N181_N189++;
            item_N179_N187 = CDR(list_val(item_N179_N187));
        }

}

        if (is_not_nil(item_N179_N187))
{
{
   
            goto error;
}

}

        if (size_N181_N189 > MAP_SMALL_MAP_LIMIT)
{
    {
{


ycf_sub_fun_trap_state_wb_N184 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_from_validated_list_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N184,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,p_N182_N190, list_N177_N185, value_N178_N186, size_N181_N189);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N184)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_maps_from_keys_2_helper;
  ycf_yield_location_label_1:;
   ycf_tmp_fun_call_tmp_var =  hashmap_from_validated_list_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N184,
                            ycf_extra_context);
}

            /* Cannot put call in return statement because
               YCF cannot handle that */
            res_N180_N188 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}

{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


            return res_N180_N188;
}
        }

} else
{
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

            /* We don't yield while constructing flatmap because
               MAP_SMALL_MAP_LIMIT is small */
	    return flatmap_from_validated_list(p_N182_N190, list_N177_N185, value_N178_N186, size_N181_N189);
}

}
    }

}

error:

    BIF_ERROR(p_N182_N190, BADARG);

{
  struct gen_ycf_trap_state_for_maps_from_keys_2_helper* ycf_my_trap_state;
  ycf_do_yield_label_maps_from_keys_2_helper:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_maps_from_keys_2_helper), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->list_N177_N185 = list_N177_N185;
    ycf_my_trap_state->value_N178_N186 = value_N178_N186;
    ycf_my_trap_state->item_N179_N187 = item_N179_N187;
    ycf_my_trap_state->res_N180_N188 = res_N180_N188;
    ycf_my_trap_state->size_N181_N189 = size_N181_N189;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N184 = ycf_sub_fun_trap_state_wb_N184;
    ycf_my_trap_state->p_N182_N190 = p_N182_N190;
    ycf_my_trap_state->bif_args_N183_N191 = bif_args_N183_N191;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   BIF_RETTYPE  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_maps_from_list_1_helper {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm list_N192_N200;
    Eterm res_N193_N201;
    Eterm *kv_N194_N202;
    Uint  size_N195_N203;
    Eterm item_N196_N204;

void* ycf_sub_fun_trap_state_wb_N199;Process* p_N197_N205; Eterm* bif_args_N198_N206;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void maps_from_list_1_helper_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_maps_from_list_1_helper* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm list_N192_N200;
    Eterm res_N193_N201;
    Eterm *kv_N194_N202;
    Uint  size_N195_N203;
    Eterm item_N196_N204;

void* ycf_sub_fun_trap_state_wb_N199;Process* p_N197_N205; Eterm* bif_args_N198_N206;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    list_N192_N200 = ycf_my_trap_state->list_N192_N200;
    res_N193_N201 = ycf_my_trap_state->res_N193_N201;
    kv_N194_N202 = ycf_my_trap_state->kv_N194_N202;
    size_N195_N203 = ycf_my_trap_state->size_N195_N203;
    item_N196_N204 = ycf_my_trap_state->item_N196_N204;
    ycf_sub_fun_trap_state_wb_N199 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N199;
    p_N197_N205 = ycf_my_trap_state->p_N197_N205;
    bif_args_N198_N206 = ycf_my_trap_state->bif_args_N198_N206;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N199 != NULL)
{     hashmap_from_validated_list_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N199);
  }
}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  BIF_RETTYPE  maps_from_list_1_helper_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_maps_from_list_1_helper* ycf_my_trap_state = *ycf_trap_state;
return maps_from_list_1_helper_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N197_N205,ycf_my_trap_state->bif_args_N198_N206)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static BIF_RETTYPE maps_from_list_1_helper_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process* p_N197_N205, Eterm* bif_args_N198_N206) {
    Eterm list_N192_N200;
    Eterm res_N193_N201;
    Eterm *kv_N194_N202;
    Uint  size_N195_N203;
    Eterm item_N196_N204;

void* ycf_sub_fun_trap_state_wb_N199;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_maps_from_list_1_helper* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    list_N192_N200 = ycf_my_trap_state->list_N192_N200;
    res_N193_N201 = ycf_my_trap_state->res_N193_N201;
    kv_N194_N202 = ycf_my_trap_state->kv_N194_N202;
    size_N195_N203 = ycf_my_trap_state->size_N195_N203;
    item_N196_N204 = ycf_my_trap_state->item_N196_N204;
    ycf_sub_fun_trap_state_wb_N199 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N199;
    p_N197_N205 = ycf_my_trap_state->p_N197_N205;
    bif_args_N198_N206 = ycf_my_trap_state->bif_args_N198_N206;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;
case 2: goto ycf_yield_location_label_2;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N199 = NULL;

}
    list_N192_N200 = bif_args_N198_N206[0];
    size_N195_N203 = 0;
    item_N196_N204 = list_N192_N200;
    if (is_list(item_N196_N204) || is_nil(item_N196_N204))
{
    {

	/* Calculate size and check validity */

	while(is_list(item_N196_N204))
{
    {
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 2;
  goto ycf_do_yield_label_maps_from_list_1_helper;
  ycf_yield_location_label_2:;
}

}
	    res_N193_N201 = CAR(list_val(item_N196_N204));
	    if (is_not_tuple(res_N193_N201))
{
{
   
		goto error;
}

}

	    kv_N194_N202 = tuple_val(res_N193_N201);
	    if (*kv_N194_N202 != make_arityval(2))
{
{
   
		goto error;
}

}

	    size_N195_N203++;
	    item_N196_N204 = CDR(list_val(item_N196_N204));
	}

}

	if (is_not_nil(item_N196_N204))
{
{
   
	    goto error;
}

}

	if (size_N195_N203 > MAP_SMALL_MAP_LIMIT)
{
    {
{


ycf_sub_fun_trap_state_wb_N199 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_from_validated_list_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N199,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,p_N197_N205, list_N192_N200, THE_NON_VALUE, size_N195_N203);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N199)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_maps_from_list_1_helper;
  ycf_yield_location_label_1:;
   ycf_tmp_fun_call_tmp_var =  hashmap_from_validated_list_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N199,
                            ycf_extra_context);
}

            /* Cannot put call in return statement because
               YCF cannot handle that */
            res_N193_N201 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}

{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


            return res_N193_N201;
}
	}

} else
{
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

            /* We don't yield while constructing flatmap because
               MAP_SMALL_MAP_LIMIT is small */
	    return flatmap_from_validated_list(p_N197_N205, list_N192_N200, THE_NON_VALUE, size_N195_N203);
}

}
    }

}

error:

    BIF_ERROR(p_N197_N205, BADARG);

{
  struct gen_ycf_trap_state_for_maps_from_list_1_helper* ycf_my_trap_state;
  ycf_do_yield_label_maps_from_list_1_helper:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_maps_from_list_1_helper), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->list_N192_N200 = list_N192_N200;
    ycf_my_trap_state->res_N193_N201 = res_N193_N201;
    ycf_my_trap_state->kv_N194_N202 = kv_N194_N202;
    ycf_my_trap_state->size_N195_N203 = size_N195_N203;
    ycf_my_trap_state->item_N196_N204 = item_N196_N204;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N199 = ycf_sub_fun_trap_state_wb_N199;
    ycf_my_trap_state->p_N197_N205 = p_N197_N205;
    ycf_my_trap_state->bif_args_N198_N206 = bif_args_N198_N206;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   BIF_RETTYPE  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN



struct gen_ycf_trap_state_for_hashmap_from_validated_list {
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm item_N213_N229;
    Eterm *hp_N214_N230;
    Eterm *kv_N215_N231;
    Eterm res_N216_N232;
    Eterm key_N217_N233;
    Eterm value_N218_N234;
    Uint32 sw_N219_N235;
    Uint32 hx_N220_N236;
    Uint ix_N221_N237;
    hxnode_t *hxns_N222_N238;
    ErtsHeapFactory *factory_N223_N239;
	Eterm *kv_N207_N240;
        Eterm *ks_N208_N241;
        Eterm *vs_N209_N242;
	flatmap_t *mp_N210_N243;
	Eterm keys_N211_N244;
        Uint n_N212_N245;
void* ycf_sub_fun_trap_state_wb_N228;Process *p_N224_N246;
                                         Eterm list_N225_N247;
                                         Eterm fill_value_N226_N248;
                                         Uint size_N227_N249;
};


/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

static void hashmap_from_validated_list_ycf_gen_destroy(void* ycf_my_trap_state_param){
     {
     struct gen_ycf_trap_state_for_hashmap_from_validated_list* ycf_my_trap_state = ycf_my_trap_state_param;
     
ycf_yield_alloc_type ycf_yield_alloc;
ycf_yield_free_type ycf_yield_free;
void* ycf_yield_alloc_free_context;
size_t ycf_stack_alloc_size_or_max_size;
void* ycf_stack_alloc_data;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;
    Eterm item_N213_N229;
    Eterm *hp_N214_N230;
    Eterm *kv_N215_N231;
    Eterm res_N216_N232;
    Eterm key_N217_N233;
    Eterm value_N218_N234;
    Uint32 sw_N219_N235;
    Uint32 hx_N220_N236;
    Uint ix_N221_N237;
    hxnode_t *hxns_N222_N238;
    ErtsHeapFactory *factory_N223_N239;
	Eterm *kv_N207_N240;
        Eterm *ks_N208_N241;
        Eterm *vs_N209_N242;
	flatmap_t *mp_N210_N243;
	Eterm keys_N211_N244;
        Uint n_N212_N245;
void* ycf_sub_fun_trap_state_wb_N228;Process *p_N224_N246;
                                         Eterm list_N225_N247;
                                         Eterm fill_value_N226_N248;
                                         Uint size_N227_N249;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    item_N213_N229 = ycf_my_trap_state->item_N213_N229;
    hp_N214_N230 = ycf_my_trap_state->hp_N214_N230;
    kv_N215_N231 = ycf_my_trap_state->kv_N215_N231;
    res_N216_N232 = ycf_my_trap_state->res_N216_N232;
    key_N217_N233 = ycf_my_trap_state->key_N217_N233;
    value_N218_N234 = ycf_my_trap_state->value_N218_N234;
    sw_N219_N235 = ycf_my_trap_state->sw_N219_N235;
    hx_N220_N236 = ycf_my_trap_state->hx_N220_N236;
    ix_N221_N237 = ycf_my_trap_state->ix_N221_N237;
    hxns_N222_N238 = ycf_my_trap_state->hxns_N222_N238;
    factory_N223_N239 = ycf_my_trap_state->factory_N223_N239;
    kv_N207_N240 = ycf_my_trap_state->kv_N207_N240;
    ks_N208_N241 = ycf_my_trap_state->ks_N208_N241;
    vs_N209_N242 = ycf_my_trap_state->vs_N209_N242;
    mp_N210_N243 = ycf_my_trap_state->mp_N210_N243;
    keys_N211_N244 = ycf_my_trap_state->keys_N211_N244;
    n_N212_N245 = ycf_my_trap_state->n_N212_N245;
    ycf_sub_fun_trap_state_wb_N228 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N228;
    p_N224_N246 = ycf_my_trap_state->p_N224_N246;
    list_N225_N247 = ycf_my_trap_state->list_N225_N247;
    fill_value_N226_N248 = ycf_my_trap_state->fill_value_N226_N248;
    size_N227_N249 = ycf_my_trap_state->size_N227_N249;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     
/* YCF SPECIAL CUSTOM CODE START */
{
  if(ycf_sub_fun_trap_state_wb_N228 != NULL)
{     hashmap_from_unsorted_array_ycf_gen_destroy(ycf_sub_fun_trap_state_wb_N228);
  }
}
{

    {
        if (hxns_N222_N238 != NULL) {
            /* Execution of this function got destroyed while yielding in
               the loop above */
            erts_free(ERTS_ALC_T_MAP_TRAP, (void *) hxns_N222_N238);
        }
    }}

/* YCF SPECIAL CUSTOM CODE END */

     ycf_destroy_stack_allocator(&ycf_frame_alloc_data, ycf_yield_free, ycf_yield_alloc_free_context);
     ycf_yield_free(ycf_my_trap_state, ycf_yield_alloc_free_context);
     }
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unused-but-set-variable)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */


/* clang-format off */
YCF_GCC_DIAG_OFF(unused-function)
/* clang-format on */

   static  Eterm  hashmap_from_validated_list_ycf_gen_continue(long* ycf_number_of_reduction_param,
                       void** ycf_trap_state,
                       void* ycf_extra_context){
     struct gen_ycf_trap_state_for_hashmap_from_validated_list* ycf_my_trap_state = *ycf_trap_state;
return hashmap_from_validated_list_ycf_gen_yielding(ycf_number_of_reduction_param,
                    ycf_trap_state,
                    ycf_extra_context,
                    ycf_my_trap_state->ycf_yield_alloc,
                    ycf_my_trap_state->ycf_yield_free,
                    ycf_my_trap_state->ycf_yield_alloc_free_context,
                    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size,
                    ycf_my_trap_state->ycf_stack_alloc_data
                    ,ycf_my_trap_state->p_N224_N246,ycf_my_trap_state->list_N225_N247,ycf_my_trap_state->fill_value_N226_N248,ycf_my_trap_state->size_N227_N249)
;
}
/* clang-format off */
YCF_GCC_DIAG_ON(unused-function)
/* clang-format on */

#define YCF_IN_YIELDING_FUN 1
#undef YCF_STACK_ALLOC
#define YCF_STACK_ALLOC(SIZE) \
    ycf_stack_alloc(SIZE,\
                    &ycf_frame_alloc_data,\
                    ycf_yield_alloc, ycf_yield_alloc_free_context,\
                     ycf_stack_alloc_size_or_max_size)

/* clang-format off */
YCF_GCC_DIAG_OFF(pragmas)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_OFF(uninitialized)
/* clang-format on */
static Eterm hashmap_from_validated_list_ycf_gen_yielding(
long* ycf_nr_of_reductions_param,
void** ycf_trap_state,
void* ycf_extra_context,
ycf_yield_alloc_type ycf_yield_alloc,
ycf_yield_free_type ycf_yield_free,
void* ycf_yield_alloc_free_context,
size_t ycf_stack_alloc_size_or_max_size,
void* ycf_stack_alloc_data,Process *p_N224_N246,
                                         Eterm list_N225_N247,
                                         Eterm fill_value_N226_N248,
                                         Uint size_N227_N249) {
    Eterm item_N213_N229;
    Eterm *hp_N214_N230;
    Eterm *kv_N215_N231;
    Eterm res_N216_N232;
    Eterm key_N217_N233;
    Eterm value_N218_N234;
    Uint32 sw_N219_N235;
    Uint32 hx_N220_N236;
    Uint ix_N221_N237;
    hxnode_t *hxns_N222_N238;
    ErtsHeapFactory *factory_N223_N239;
	Eterm *kv_N207_N240;
        Eterm *ks_N208_N241;
        Eterm *vs_N209_N242;
	flatmap_t *mp_N210_N243;
	Eterm keys_N211_N244;
        Uint n_N212_N245;
void* ycf_sub_fun_trap_state_wb_N228;
int ycf_trap_location;
long ycf_nr_of_reductions;
struct ycf_alloc_data ycf_frame_alloc_data;

{
  
  ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
  ycf_frame_alloc_data.size = 0;
  ycf_frame_alloc_data.max_size = ycf_stack_alloc_size_or_max_size;
  ycf_frame_alloc_data.data = ycf_stack_alloc_data;
  ycf_frame_alloc_data.needs_freeing = 0;
  if(*ycf_trap_state != NULL){
     struct gen_ycf_trap_state_for_hashmap_from_validated_list* ycf_my_trap_state = *ycf_trap_state;
     
    ycf_yield_alloc = ycf_my_trap_state->ycf_yield_alloc;
    ycf_yield_free = ycf_my_trap_state->ycf_yield_free;
    ycf_yield_alloc_free_context = ycf_my_trap_state->ycf_yield_alloc_free_context;
    ycf_stack_alloc_size_or_max_size = ycf_my_trap_state->ycf_stack_alloc_size_or_max_size;
    ycf_stack_alloc_data = ycf_my_trap_state->ycf_stack_alloc_data;
    ycf_trap_location = ycf_my_trap_state->ycf_trap_location;
    ycf_nr_of_reductions = ycf_my_trap_state->ycf_nr_of_reductions;
    ycf_frame_alloc_data = ycf_my_trap_state->ycf_frame_alloc_data;
    item_N213_N229 = ycf_my_trap_state->item_N213_N229;
    hp_N214_N230 = ycf_my_trap_state->hp_N214_N230;
    kv_N215_N231 = ycf_my_trap_state->kv_N215_N231;
    res_N216_N232 = ycf_my_trap_state->res_N216_N232;
    key_N217_N233 = ycf_my_trap_state->key_N217_N233;
    value_N218_N234 = ycf_my_trap_state->value_N218_N234;
    sw_N219_N235 = ycf_my_trap_state->sw_N219_N235;
    hx_N220_N236 = ycf_my_trap_state->hx_N220_N236;
    ix_N221_N237 = ycf_my_trap_state->ix_N221_N237;
    hxns_N222_N238 = ycf_my_trap_state->hxns_N222_N238;
    factory_N223_N239 = ycf_my_trap_state->factory_N223_N239;
    kv_N207_N240 = ycf_my_trap_state->kv_N207_N240;
    ks_N208_N241 = ycf_my_trap_state->ks_N208_N241;
    vs_N209_N242 = ycf_my_trap_state->vs_N209_N242;
    mp_N210_N243 = ycf_my_trap_state->mp_N210_N243;
    keys_N211_N244 = ycf_my_trap_state->keys_N211_N244;
    n_N212_N245 = ycf_my_trap_state->n_N212_N245;
    ycf_sub_fun_trap_state_wb_N228 = ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N228;
    p_N224_N246 = ycf_my_trap_state->p_N224_N246;
    list_N225_N247 = ycf_my_trap_state->list_N225_N247;
    fill_value_N226_N248 = ycf_my_trap_state->fill_value_N226_N248;
    size_N227_N249 = ycf_my_trap_state->size_N227_N249;

     
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

     ycf_nr_of_reductions = *ycf_nr_of_reductions_param;
     switch(ycf_trap_location){
case 1: goto ycf_yield_location_label_1;
case 2: goto ycf_yield_location_label_2;

}
  }
}
{

ycf_sub_fun_trap_state_wb_N228 = NULL;

}
    item_N213_N229 = list_N225_N247;
    ix_N221_N237 = 0;
#ifdef NOT_YCF_YIELDING_VERSION
    /* Macro to make YCF ignore declarations */
#define YCF_IGNORE(X) X
    YCF_IGNORE(ErtsHeapFactory factory_instance;)
#undef YCF_IGNORE
    factory_N223_N239 = &factory_instance;
#else
    factory_N223_N239 = YCF_STACK_ALLOC(sizeof(ErtsHeapFactory));
#endif
    ASSERT(size_N227_N249 > 0);

    hp_N214_N230 = HAlloc(p_N224_N246, (2 * size_N227_N249));

    /* create tmp hx values and leaf ptrs */
    hxns_N222_N238 = (hxnode_t *)erts_alloc(ERTS_ALC_T_MAP_TRAP, size_N227_N249 * sizeof(hxnode_t));

    while(is_list(item_N213_N229))
{
    {
{
ycf_nr_of_reductions = ycf_nr_of_reductions - (1);
if (ycf_nr_of_reductions <= 0) {
  ycf_trap_location = 2;
  goto ycf_do_yield_label_hashmap_from_validated_list;
  ycf_yield_location_label_2:;
}

}
	res_N216_N232 = CAR(list_val(item_N213_N229));
	if(is_value(fill_value_N226_N248))
{
    {
	    key_N217_N233 = res_N216_N232;
	    value_N218_N234 = fill_value_N226_N248;
	}

} else
{
    {
	    kv_N215_N231 = tuple_val(res_N216_N232);
	    key_N217_N233 = kv_N215_N231[1];
	    value_N218_N234 = kv_N215_N231[2];
	}

}
	hx_N220_N236  = hashmap_restore_hash(0,key_N217_N233);
	swizzle32(sw_N219_N235,hx_N220_N236);
	hxns_N222_N238[ix_N221_N237].hx   = sw_N219_N235;
	hxns_N222_N238[ix_N221_N237].val  = CONS(hp_N214_N230, key_N217_N233, value_N218_N234); hp_N214_N230 += 2;
	hxns_N222_N238[ix_N221_N237].skip = 1; /* will be reassigned in from_array */
	hxns_N222_N238[ix_N221_N237].i    = ix_N221_N237;
	ix_N221_N237++;
	item_N213_N229 = CDR(list_val(item_N213_N229));
    }

}

    erts_factory_proc_init(factory_N223_N239, p_N224_N246);
{

ycf_sub_fun_trap_state_wb_N228 = NULL;
{
  Eterm  ycf_tmp_fun_call_tmp_var;
ycf_tmp_fun_call_tmp_var =  hashmap_from_unsorted_array_ycf_gen_yielding(&ycf_nr_of_reductions,
                         &ycf_sub_fun_trap_state_wb_N228,ycf_extra_context,
                         ycf_yield_alloc,ycf_yield_free,
                         ycf_yield_alloc_free_context,
                         YCF_ALLOC_NEXT_MAX_SIZE(),
                         YCF_ALLOC_NEXT_BLOCK()
                         ,factory_N223_N239, hxns_N222_N238, size_N227_N249, 0, ERTS_ALC_T_MAP_TRAP);
while(YCF_IS_YIELDED(ycf_sub_fun_trap_state_wb_N228)){
   ycf_trap_location = 1;
   goto ycf_do_yield_label_hashmap_from_validated_list;
  ycf_yield_location_label_1:;
   ycf_tmp_fun_call_tmp_var =  hashmap_from_unsorted_array_ycf_gen_continue(&ycf_nr_of_reductions,
                            &ycf_sub_fun_trap_state_wb_N228,
                            ycf_extra_context);
}

    res_N216_N232 = ycf_tmp_fun_call_tmp_var;


}
/* YCF Replaced special code */

}

    erts_factory_close(factory_N223_N239);
/* YCF Replaced special code */


    erts_free(ERTS_ALC_T_MAP_TRAP, (void *) hxns_N222_N238);
    /* Memory management depends on the line below */
    hxns_N222_N238 = NULL;
    ERTS_VERIFY_UNUSED_TEMP_ALLOC(p_N224_N246);
    
   /* No yielding in the loops below as the number of loop
      iterations must be small */

    if (hashmap_size(res_N216_N232) <= MAP_SMALL_MAP_LIMIT)
{
    {
        DECLARE_WSTACK(wstack);
{

/* moved declaration (kv)*/

}
{

/* moved declaration (ks)*/

}
{

/* moved declaration (vs)*/

}
{

/* moved declaration (mp)*/

}
{

/* moved declaration (keys)*/

}
        n_N212_N245 = hashmap_size(res_N216_N232);
        ASSERT(n_N212_N245 > 0);
	/* build flat structure */
	hp_N214_N230    = HAlloc(p_N224_N246, 3 + 1 + (2 * n_N212_N245));
	keys_N211_N244  = make_tuple(hp_N214_N230);
	*hp_N214_N230++ = make_arityval(n_N212_N245);
	ks_N208_N241    = hp_N214_N230;
	hp_N214_N230   += n_N212_N245;
	mp_N210_N243    = (flatmap_t*)hp_N214_N230;
	hp_N214_N230   += MAP_HEADER_FLATMAP_SZ;
	vs_N209_N242    = hp_N214_N230;

	mp_N210_N243->thing_word = MAP_HEADER_FLATMAP;
	mp_N210_N243->size = n_N212_N245;
	mp_N210_N243->keys = keys_N211_N244;

	hashmap_iterator_init(&wstack, res_N216_N232, 0);

	while ((kv_N207_N240=hashmap_iterator_next(&wstack)) != NULL)
{
    {
	    *ks_N208_N241++ = CAR(kv_N207_N240);
	    *vs_N209_N242++ = CDR(kv_N207_N240);
	}

}

	/* it cannot have multiple keys */
	erts_validate_and_sort_flatmap(mp_N210_N243);

	DESTROY_WSTACK(wstack);
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

	return make_flatmap(mp_N210_N243);
}
    }

}
{

if (*ycf_trap_state != NULL) {
   ycf_yield_free(*ycf_trap_state, ycf_yield_alloc_free_context);
   *ycf_trap_state = NULL;
}
ycf_destroy_stack_allocator(&ycf_frame_alloc_data,
                            ycf_yield_free,
                            ycf_yield_alloc_free_context);
*ycf_nr_of_reductions_param = ycf_nr_of_reductions;
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */

/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */


    return res_N216_N232;
}

{
  struct gen_ycf_trap_state_for_hashmap_from_validated_list* ycf_my_trap_state;
  ycf_do_yield_label_hashmap_from_validated_list:;
  
/* YCF SPECIAL CUSTOM CODE START */

/* YCF SPECIAL CUSTOM CODE END */
  if (*ycf_trap_state == NULL) {
    ycf_my_trap_state = ycf_yield_alloc(sizeof(struct gen_ycf_trap_state_for_hashmap_from_validated_list), ycf_yield_alloc_free_context);
      } else {
    ycf_my_trap_state = *ycf_trap_state;
  }
      ycf_my_trap_state->ycf_yield_alloc = ycf_yield_alloc;
    ycf_my_trap_state->ycf_yield_free = ycf_yield_free;
    ycf_my_trap_state->ycf_yield_alloc_free_context = ycf_yield_alloc_free_context;
    ycf_my_trap_state->ycf_stack_alloc_size_or_max_size = ycf_stack_alloc_size_or_max_size;
    ycf_my_trap_state->ycf_stack_alloc_data = ycf_stack_alloc_data;
    ycf_my_trap_state->ycf_trap_location = ycf_trap_location;
    ycf_my_trap_state->ycf_nr_of_reductions = ycf_nr_of_reductions;
    ycf_my_trap_state->ycf_frame_alloc_data = ycf_frame_alloc_data;
    ycf_my_trap_state->item_N213_N229 = item_N213_N229;
    ycf_my_trap_state->hp_N214_N230 = hp_N214_N230;
    ycf_my_trap_state->kv_N215_N231 = kv_N215_N231;
    ycf_my_trap_state->res_N216_N232 = res_N216_N232;
    ycf_my_trap_state->key_N217_N233 = key_N217_N233;
    ycf_my_trap_state->value_N218_N234 = value_N218_N234;
    ycf_my_trap_state->sw_N219_N235 = sw_N219_N235;
    ycf_my_trap_state->hx_N220_N236 = hx_N220_N236;
    ycf_my_trap_state->ix_N221_N237 = ix_N221_N237;
    ycf_my_trap_state->hxns_N222_N238 = hxns_N222_N238;
    ycf_my_trap_state->factory_N223_N239 = factory_N223_N239;
    ycf_my_trap_state->kv_N207_N240 = kv_N207_N240;
    ycf_my_trap_state->ks_N208_N241 = ks_N208_N241;
    ycf_my_trap_state->vs_N209_N242 = vs_N209_N242;
    ycf_my_trap_state->mp_N210_N243 = mp_N210_N243;
    ycf_my_trap_state->keys_N211_N244 = keys_N211_N244;
    ycf_my_trap_state->n_N212_N245 = n_N212_N245;
    ycf_my_trap_state->ycf_sub_fun_trap_state_wb_N228 = ycf_sub_fun_trap_state_wb_N228;
    ycf_my_trap_state->p_N224_N246 = p_N224_N246;
    ycf_my_trap_state->list_N225_N247 = list_N225_N247;
    ycf_my_trap_state->fill_value_N226_N248 = fill_value_N226_N248;
    ycf_my_trap_state->size_N227_N249 = size_N227_N249;

  *ycf_nr_of_reductions_param = ycf_nr_of_reductions;
  *ycf_trap_state = ycf_my_trap_state;
      {
    static   Eterm  const ycf_unused_ret_value;
    return ycf_unused_ret_value;
  }

}
}
/* clang-format off */
YCF_GCC_DIAG_ON(uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(maybe-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(sometimes-uninitialized)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(unknown-warning-option)
/* clang-format on */

/* clang-format off */
YCF_GCC_DIAG_ON(pragmas)
/* clang-format on */

#undef YCF_STACK_ALLOC
#undef YCF_IN_YIELDING_FUN
